/*

  This file is part of sniffer, a packet capture utility and
  network moniter
  The author can be contacted at <mistral@stev.org>
  the lastest version is avilable from 
  http://stev.org

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "config.h"

#ifdef ARP
#ifdef ARP_48BIT

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <pthread.h>
#include <fcntl.h>

#include <sys/stat.h>

#include "sniff.h"
#include "list.h"
#include "locks.h"
#include "gui_main.h"
#include "in_ntoa.h"
#include "lookup.h"
#include "arp.h"
#include "arp_48bit.h"
#include "stat.h"
#include "log.h"

unsigned long int inet_addr(const char *cp);

pthread_mutex_t arp_48bit_mutex =  PTHREAD_MUTEX_INITIALIZER;
struct list_t *arp_48bit_ven;	/* for a list of vendors to be stored */
struct list_t *arp_48bit_data; 	/* list for 48 bit arp addresses on network */

unsigned long long arp_48bit_stats_requests = 0;
unsigned long long arp_48bit_stats_replies  = 0;
unsigned long long arp_48bit_stats_dropped  = 0;
unsigned long long arp_48bit_stats_errors   = 0;

int arp_handle_48bit(struct sniff_pkt *pkt, struct arphdr *in, void *data) {
	struct arp_48bit *packet;	/* the contents of the packet */
	/* get out data */

	pkt->func = "arp_handle_48bit";
	if (pkt->dataleft < sizeof(struct arp_48bit))
		return ERR_DATA;

	packet = (struct arp_48bit *) data;
	pkt->dataleft -= sizeof(struct arp_48bit);

	switch(ntohs(in->ar_op)) {
		case ARPOP_REQUEST: /* look for the recivers */
			arp_48bit_stats_requests++;
			return arp_48bit_request(pkt, packet);
			break;
		case ARPOP_REPLY: /* we look for the sender this time */
			arp_48bit_stats_replies++;
			return arp_48bit_reply(pkt, packet);
			break;
/* FIXME: need reverse arp done */
		case ARPOP_RREQUEST:
		case ARPOP_RREPLY:
		default:
			arp_48bit_stats_dropped++;
			return ERR_SUPP;
	}
	log_unreach();
	return ERR_MISC;
}

inline int arp_48bit_reply(struct sniff_pkt *pkt, struct arp_48bit *packet) {
	struct arp_48bit_data_t tmp;
	struct arp_48bit_data_t *record;
	char ipstr[16];
	int index;

	pkt->func = "arp_48bit_reply";

	sprintf(&ipstr[0], "%d.%d.%d.%d", 
			packet->sip[0], packet->sip[1],
			packet->sip[2], packet->sip[3]);

	tmp.ip = inet_addr(ipstr);
	tmp.if_index = pkt->if_index;

	SLOCK(&arp_48bit_mutex);

	index = list_search(arp_48bit_data, &tmp);
	if (index < 0) {
		/* we do not have a struct lets set 1 up */
		record = malloc( sizeof(struct arp_48bit_data_t) );
		if (!record) {
			arp_48bit_stats_errors++;
			log_errno("malloc");
/* unlock */		SUNLOCK(&arp_48bit_mutex);
			return ERR_OOM;
		}
		bzero(record, sizeof(struct arp_48bit_data_t));
		record->if_index = pkt->if_index;
		record->if_name = pkt->if_name;
		record->ip = tmp.ip;
		record->str_addr = in_ntoa(record->ip);
		record->str_name = NULL;
		record->str_vendor = NULL; /* this gets set futher down */
		record->last = time(NULL);
		record->first = 1;
		list_add_sort(arp_48bit_data, record);
	} else {
		record = list_get(arp_48bit_data, index);
	}

	/* modify record as we need to */
	if (memcmp(&record->hw[0], &packet->shw[0], ETH_ALEN) != 0) {
		if (!record->first) {
			if (arp_log)
				fprintf(arp_log, "REPLY ADDREES (%.2X:%.2X:%.2X:%.2X:%.2X:%.2X) changed to (%.2X:%.2X:%.2X:%.2X:%.2X:%.2X) on %s for %s\n"
						,record->hw[0], record->hw[1], record->hw[2]
						,record->hw[3], record->hw[4], record->hw[5]
						,packet->shw[0], packet->shw[1], packet->shw[2]
						,packet->shw[3], packet->shw[4], packet->shw[5]
						,record->if_name, lookup(record->ip, 0));
						
		} else {
			if (arp_log)
				fprintf(arp_log, "REPLY NEW (%.2X:%.2X:%.2X:%.2X:%.2X:%.2X) on %s for %s\n"
						,packet->shw[0], packet->shw[1], packet->shw[2]
						,packet->shw[3], packet->shw[4], packet->shw[5]
						,record->if_name, lookup(record->ip, 0));
		}
		memcpy(&record->hw[0], &packet->shw[0], ETH_ALEN);
		record->first = 0;
		/* set the vendor name */
		arp_48bit_set_vendor(record);
	}

	record->last = time(NULL);

	SUNLOCK(&arp_48bit_mutex);
	return 0;
}

inline int arp_48bit_request(struct sniff_pkt *pkt, struct arp_48bit *packet) {
	struct arp_48bit_data_t tmp;
	struct arp_48bit_data_t *record;
	char ipstr[16];
	int index;

	pkt->func = "arp_48bit_request";

	sprintf(&ipstr[0], "%d.%d.%d.%d", 
			packet->rip[0], packet->rip[1],
			packet->rip[2], packet->rip[3]);

	tmp.ip = inet_addr(ipstr);
	tmp.if_index = pkt->if_index;

	SLOCK(&arp_48bit_mutex);

	index = list_search(arp_48bit_data, &tmp);
	if (index < 0) {
		/* we do not have a struct lets set 1 up */
		record = malloc( sizeof(struct arp_48bit_data_t) );
		if (!record) {
			arp_48bit_stats_errors++;
			log_errno("malloc");
/* unlock */		SUNLOCK(&arp_48bit_mutex);
			return ERR_OOM;
		}
		bzero(record, sizeof(struct arp_48bit_data_t));
		record->if_index = pkt->if_index;
		record->if_name = pkt->if_name;
		record->ip = tmp.ip;
		record->str_addr = in_ntoa(record->ip);
		record->str_name = NULL;
		record->str_vendor = NULL; /* this cannot be set because we do not have the info */
		record->last = time(NULL);
		record->first = 1;
		list_add_sort(arp_48bit_data, record);
	} else {
		record = list_get(arp_48bit_data, index);
	}

	/* modify record */
	record->last = time(NULL);

	SUNLOCK(&arp_48bit_mutex);
	return 0;
}

int arp_48bit_cmp_ip(struct arp_48bit_data_t *c1, struct arp_48bit_data_t *c2) {
	unsigned long ip1, ip2;
	ip1 = ntohl(c1->ip);
	ip2 = ntohl(c2->ip);
	if (ip1 > ip2) return -1;
	if (ip1 < ip2) return 1;
	if (c1->if_index > c2->if_index) return -1;
	if (c2->if_index < c2->if_index) return 1;
	return 0;
}

/**************************************
* set the vendor string in the struct
* to a the vendor or NULL
**************************************/

void arp_48bit_set_vendor(struct arp_48bit_data_t *data) {
	struct arp_48bit_vendor tmp;
	struct arp_48bit_vendor *res;
	int index;

	/* set up the first 3 bytes of the fake struct tmp */
	memcpy(&tmp.hw, &data->hw, ETH_ALEN);
	tmp.hw[3] = 0;
	tmp.hw[4] = 0;
	tmp.hw[5] = 0;

	/* get a value in out list of data */
	index = list_search(arp_48bit_ven, &tmp);

	if (index < 0) {
		/* we dont have the data */
		data->str_vendor = NULL;
		return;
	} else {
		/* we have the data so just make it point to it */
		res = list_get(arp_48bit_ven, index);
		data->str_vendor = res->string;
		return;		
	}

	return;
}

/*******************************************
* the first 3 bytes of the MAC address
* contain the vendor id of the address
* this function does this and
*******************************************/

int arp_48bit_cmp_vendors(struct arp_48bit_vendor *c1, struct arp_48bit_vendor *c2) {
	/* We only need to compare the first 3 bytes */
	return memcmp(c1->hw, c2->hw, 3);
}

/****************************
* this is only called at the 
* start of the program
* to set up data structs
****************************/

int arp_48bit_init() {
	int i = 0;

	SLOCK(&arp_48bit_mutex);
	arp_48bit_ven = list_init();
	list_setcmp(arp_48bit_ven, (void *) &arp_48bit_cmp_vendors);

	arp_48bit_data = list_init();
	list_setcmp(arp_48bit_data, (void *) &arp_48bit_cmp_ip);

	/* fill our live data list for the arp vendors list */
	while(arp_48bit_vendors[i].string != NULL) {
		if (list_add_sort(arp_48bit_ven, &arp_48bit_vendors[i]) < 0)
			log_s("error adding to list");
		i++;
	}

	SUNLOCK(&arp_48bit_mutex);
	return 0;
}

void arp_gui_48bit(struct gui_t *p, int y, int x) {
	WINDOW *draw;
	struct arp_48bit_data_t *record;
	int len, i, offset, cury;
	char *foot_back, buff[80];

	/* create a new window */
	draw = newwin(p->twin->_maxy - 1, p->twin->_maxx - 1, 1, 1);
	if (!draw) {
		log_s("newwin() failed");
		return;
	}
	wbkgd(draw, COLOR_PAIR(COLOR_NORMAL));
	werase(draw);

	offset = 0;
	foot_back = p->footer;

	while(1) {
		werase(draw);
		cury = 0;

		SLOCK(&arp_48bit_mutex);
		len = list_length(arp_48bit_data);

		snprintf(&buff[0], 80, "Total Entries: %d Requests: %llu Replies: %llu Err: %llu Drop: %llu",
				len, arp_48bit_stats_requests, arp_48bit_stats_replies,
				arp_48bit_stats_errors, arp_48bit_stats_dropped);
		gui_footer(p, &buff[0]);
		
		if (offset > 0)
			mvwprintw(draw, cury, draw->_maxx - 12, " --more-- ");

		/* check we have something to print to the screen */
		if (len == 0) {
			mvwprintw(draw, cury, 0, "No Entries");
		} else {
			i = offset;
			/* loop and print stuff to the screen */
			while(i < len && cury < draw->_maxy) {
				record = list_get(arp_48bit_data, i);
				if (record->str_name) {
					mvwprintw(draw, cury++, 0, "%5s\t%20s %.2X:%.2X:%.2X:%.2X:%.2X:%.2X %s", 
							record->if_name, record->str_name,
							record->hw[0], record->hw[1], record->hw[2],
							record->hw[3], record->hw[4], record->hw[5], record->str_vendor);
				} else { /* we dont have a name yet */
					mvwprintw(draw, cury++, 0, "%5s\t%20s %.2X:%.2X:%.2X:%.2X:%.2X:%.2X %s", 
							record->if_name, record->str_addr,
							record->hw[0], record->hw[1], record->hw[2],
							record->hw[3], record->hw[4], record->hw[5], record->str_vendor);
					record->str_name = lookup(record->ip, 1);
				}
				i++;
			}
		}

		if (cury < draw->_maxy) {
			mvwprintw(draw, cury, 0, " -- END --");
			wclrtoeol(draw);
		}

		/* do we have more info off screen ? */
		if (cury > draw->_maxy - 1)
			mvwprintw(draw, draw->_maxy , draw->_maxx - 12, "--more--");

		SUNLOCK(&arp_48bit_mutex);

		/* update the screen */
		wrefresh(draw);
		switch(gui_scroll(1, 0, len, &offset)) {
			case -1: /* error / timeout */
				break;
			case 0:	/* it did something */
				break;
			default:
				goto get_out;
				break;
		} /* end switch gui_utils_scroll */
	} /* end while(1) */

get_out:
	/* cleaup */
	gui_footer(p, foot_back);
	werase(draw);
	wrefresh(draw);
	delwin(draw);
	return;
}

struct arp_48bit_vendor arp_48bit_vendors[] = {
{ {0x00, 0x00, 0x00,0x00,0x00,0x00}, ""},
{ {0x00, 0x00, 0x01,0x00,0x00,0x00}, "SuperLAN-2U"},
{ {0x00, 0x00, 0x02,0x00,0x00,0x00}, "BBN (was internal usage only, no longer used)"},
{ {0x00, 0x00, 0x09,0x00,0x00,0x00}, "powerpipes?"},
{ {0x00, 0x00, 0x0C,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x00, 0x0E,0x00,0x00,0x00}, "Fujitsu"},
{ {0x00, 0x00, 0x0F,0x00,0x00,0x00}, "NeXT"},
{ {0x00, 0x00, 0x10,0x00,0x00,0x00}, "Hughes LAN Systems (formerly Sytek)"},
{ {0x00, 0x00, 0x11,0x00,0x00,0x00}, "Tektronix"},
{ {0x00, 0x00, 0x15,0x00,0x00,0x00}, "Datapoint Corporation"},
{ {0x00, 0x00, 0x18,0x00,0x00,0x00}, "Webster Computer Corporation Appletalk/Ethernet Gateway"},
{ {0x00, 0x00, 0x1A,0x00,0x00,0x00}, "AMD (?)"},
{ {0x00, 0x00, 0x1B,0x00,0x00,0x00}, "Novell (now Eagle Technology)"},
{ {0x00, 0x00, 0x1C,0x00,0x00,0x00}, "JDR Microdevices generic, NE2000 drivers"},
{ {0x00, 0x00, 0x1D,0x00,0x00,0x00}, "Cabletron"},
{ {0x00, 0x00, 0x1F,0x00,0x00,0x00}, "Cryptall Communications Corp."},
{ {0x00, 0x00, 0x20,0x00,0x00,0x00}, "DIAB (Data Intdustrier AB)"},
{ {0x00, 0x00, 0x21,0x00,0x00,0x00}, "SC&C (PAM Soft&Hardware also reported)"},
{ {0x00, 0x00, 0x22,0x00,0x00,0x00}, "Visual Technology"},
{ {0x00, 0x00, 0x23,0x00,0x00,0x00}, "ABB Automation AB, Dept. Q"},
{ {0x00, 0x00, 0x24,0x00,0x00,0x00}, "Olicom"},
{ {0x00, 0x00, 0x29,0x00,0x00,0x00}, "IMC"},
{ {0x00, 0x00, 0x2A,0x00,0x00,0x00}, "TRW"},
{ {0x00, 0x00, 0x2C,0x00,0x00,0x00}, "NRC - Network Resources Corporation - MultiGate Hub1+, Hub2, etc"},
{ {0x00, 0x00, 0x32,0x00,0x00,0x00}, "GPT Limited (reassigned from GEC Computers Ltd)"},
{ {0x00, 0x00, 0x37,0x00,0x00,0x00}, "Oxford Metrics Ltd"},
{ {0x00, 0x00, 0x3B,0x00,0x00,0x00}, "Hyundai/Axil Sun clones"},
{ {0x00, 0x00, 0x3C,0x00,0x00,0x00}, "Auspex"},
{ {0x00, 0x00, 0x3D,0x00,0x00,0x00}, "AT&T"},
{ {0x00, 0x00, 0x3F,0x00,0x00,0x00}, "Syntrex Inc"},
{ {0x00, 0x00, 0x44,0x00,0x00,0x00}, "Castelle"},
{ {0x00, 0x00, 0x46,0x00,0x00,0x00}, "ISC-Bunker Ramo, An Olivetti Company"},
{ {0x00, 0x00, 0x48,0x00,0x00,0x00}, "Epson"},
{ {0x00, 0x00, 0x49,0x00,0x00,0x00}, "Apricot Ltd."},
{ {0x00, 0x00, 0x4B,0x00,0x00,0x00}, "APT -ICL also reported"},
{ {0x00, 0x00, 0x4C,0x00,0x00,0x00}, "NEC Corporation"},
{ {0x00, 0x00, 0x4F,0x00,0x00,0x00}, "Logicraft 386-Ware P.C. Emulator"},
{ {0x00, 0x00, 0x51,0x00,0x00,0x00}, "Hob Electronic Gmbh & Co. KG"},
{ {0x00, 0x00, 0x52,0x00,0x00,0x00}, "Optical Data Systems"},
{ {0x00, 0x00, 0x55,0x00,0x00,0x00}, "AT&T"},
{ {0x00, 0x00, 0x58,0x00,0x00,0x00}, "Racore Computer Products Inc"},
{ {0x00, 0x00, 0x5A,0x00,0x00,0x00}, "SK (Schneider & Koch in Europe and Syskonnect outside of Europe)"},
{ {0x00, 0x00, 0x5A,0x00,0x00,0x00}, "Xerox 806 (unregistered)"},
{ {0x00, 0x00, 0x5B,0x00,0x00,0x00}, "Eltec"},
{ {0x00, 0x00, 0x5D,0x00,0x00,0x00}, "RCE"},
{ {0x00, 0x00, 0x5E,0x00,0x00,0x00}, "U.S. Department of Defense (IANA)"},
{ {0x00, 0x00, 0x5F,0x00,0x00,0x00}, "Sumitomo"},
{ {0x00, 0x00, 0x61,0x00,0x00,0x00}, "Gateway Communications"},
{ {0x00, 0x00, 0x62,0x00,0x00,0x00}, "Honeywell"},
{ {0x00, 0x00, 0x63,0x00,0x00,0x00}, "Hewlett-Packard LanProbe"},
{ {0x00, 0x00, 0x64,0x00,0x00,0x00}, "Yokogawa Digital Computer Corp"},
{ {0x00, 0x00, 0x65,0x00,0x00,0x00}, "Network General"},
{ {0x00, 0x00, 0x66,0x00,0x00,0x00}, "Talaris"},
{ {0x00, 0x00, 0x68,0x00,0x00,0x00}, "Rosemount Controls"},
{ {0x00, 0x00, 0x69,0x00,0x00,0x00}, "Concord Communications, Inc (although someone said Silicon Graphics)"},
{ {0x00, 0x00, 0x6B,0x00,0x00,0x00}, "MIPS"},
{ {0x00, 0x00, 0x6D,0x00,0x00,0x00}, "Case"},
{ {0x00, 0x00, 0x6E,0x00,0x00,0x00}, "Artisoft, Inc."},
{ {0x00, 0x00, 0x6F,0x00,0x00,0x00}, "Madge Networks Ltd. Token-ring adapters"},
{ {0x00, 0x00, 0x73,0x00,0x00,0x00}, "DuPont"},
{ {0x00, 0x00, 0x75,0x00,0x00,0x00}, "Bell Northern Research (BNR)"},
{ {0x00, 0x00, 0x77,0x00,0x00,0x00}, "Interphase [Used in other systems, e.g. MIPS, Motorola]"},
{ {0x00, 0x00, 0x78,0x00,0x00,0x00}, "Labtam Australia"},
{ {0x00, 0x00, 0x79,0x00,0x00,0x00}, "Networth Incorporated [bought by Compaq, used in Netelligent series]"},
{ {0x00, 0x00, 0x7A,0x00,0x00,0x00}, "Ardent"},
{ {0x00, 0x00, 0x7B,0x00,0x00,0x00}, "Research Machines"},
{ {0x00, 0x00, 0x7D,0x00,0x00,0x00}, "Cray Research Superservers,Inc [Also Harris (3M) (old)]"},
{ {0x00, 0x00, 0x7E,0x00,0x00,0x00}, "NetFRAME multiprocessor network servers"},
{ {0x00, 0x00, 0x7F,0x00,0x00,0x00}, "Linotype-Hell AG Linotronic typesetters"},
{ {0x00, 0x00, 0x80,0x00,0x00,0x00}, "Cray Communications (formerly Dowty Network Services)"},
{ {0x00, 0x00, 0x81,0x00,0x00,0x00}, "Synoptics"},
{ {0x00, 0x00, 0x83,0x00,0x00,0x00}, "Tadpole Technology [had Optical Data Systems which is wrong according to both]"},
{ {0x00, 0x00, 0x84,0x00,0x00,0x00}, "Aquila (?), ADI Systems Inc.(?)"},
{ {0x00, 0x00, 0x86,0x00,0x00,0x00}, "Gateway Communications Inc. (then Megahertz & now 3com)"},
{ {0x00, 0x00, 0x87,0x00,0x00,0x00}, "Hitachi"},
{ {0x00, 0x00, 0x89,0x00,0x00,0x00}, "Cayman Systems Gatorbox"},
{ {0x00, 0x00, 0x8A,0x00,0x00,0x00}, "Datahouse Information Systems"},
{ {0x00, 0x00, 0x8E,0x00,0x00,0x00}, "Solbourne(?), Jupiter(?) (I've had confirming mail on Solbourne)"},
{ {0x00, 0x00, 0x92,0x00,0x00,0x00}, "Unisys, Cogent (both reported)"},
{ {0x00, 0x00, 0x93,0x00,0x00,0x00}, "Proteon"},
{ {0x00, 0x00, 0x94,0x00,0x00,0x00}, "Asante MAC"},
{ {0x00, 0x00, 0x95,0x00,0x00,0x00}, "Sony/Tektronix"},
{ {0x00, 0x00, 0x97,0x00,0x00,0x00}, "Epoch"},
{ {0x00, 0x00, 0x98,0x00,0x00,0x00}, "Cross Com"},
{ {0x00, 0x00, 0x99,0x00,0x00,0x00}, "Memorex Telex Corporations"},
{ {0x00, 0x00, 0x9F,0x00,0x00,0x00}, "Ameristar Technology"},
{ {0x00, 0x00, 0xA0,0x00,0x00,0x00}, "Sanyo Electronics"},
{ {0x00, 0x00, 0xA2,0x00,0x00,0x00}, "Wellfleet"},
{ {0x00, 0x00, 0xA3,0x00,0x00,0x00}, "Network Application Technology (NAT)"},
{ {0x00, 0x00, 0xA4,0x00,0x00,0x00}, "Acorn"},
{ {0x00, 0x00, 0xA5,0x00,0x00,0x00}, "Compatible Systems Corporation"},
{ {0x00, 0x00, 0xA6,0x00,0x00,0x00}, "Network General (internal assignment, not for products)"},
{ {0x00, 0x00, 0xA7,0x00,0x00,0x00}, "Network Computing Devices (NCD) X-terminals"},
{ {0x00, 0x00, 0xA8,0x00,0x00,0x00}, "Stratus Computer, Inc."},
{ {0x00, 0x00, 0xA9,0x00,0x00,0x00}, "Network Systems"},
{ {0x00, 0x00, 0xAA,0x00,0x00,0x00}, "Xerox Xerox machines"},
{ {0x00, 0x00, 0xAC,0x00,0x00,0x00}, "Conware Netzpartner [had Apollo, claimed incorrect]"},
{ {0x00, 0x00, 0xAE,0x00,0x00,0x00}, "Dassault Automatismes et Telecommunications"},
{ {0x00, 0x00, 0xAF,0x00,0x00,0x00}, "Nuclear Data Acquisition Interface Modules (AIM)"},
{ {0x00, 0x00, 0xB0,0x00,0x00,0x00}, "RND (RAD Network Devices)"},
{ {0x00, 0x00, 0xB1,0x00,0x00,0x00}, "Alpha Microsystems Inc."},
{ {0x00, 0x00, 0xB3,0x00,0x00,0x00}, "CIMLinc"},
{ {0x00, 0x00, 0xB4,0x00,0x00,0x00}, "Edimax"},
{ {0x00, 0x00, 0xB5,0x00,0x00,0x00}, "Datability Terminal Servers"},
{ {0x00, 0x00, 0xB6,0x00,0x00,0x00}, "Micro-matic Research"},
{ {0x00, 0x00, 0xB7,0x00,0x00,0x00}, "Dove Fastnet"},
{ {0x00, 0x00, 0xBB,0x00,0x00,0x00}, "TRI-DATA Systems Inc. Netway products, 3274 emulators"},
{ {0x00, 0x00, 0xBC,0x00,0x00,0x00}, "Allen-Bradley"},
{ {0x00, 0x00, 0xC0,0x00,0x00,0x00}, "Western Digital now SMC (Std. Microsystems Corp.)"},
{ {0x00, 0x00, 0xC1,0x00,0x00,0x00}, "Olicom A/S"},
{ {0x00, 0x00, 0xC5,0x00,0x00,0x00}, "Farallon Computing Inc"},
{ {0x00, 0x00, 0xC6,0x00,0x00,0x00}, "HP Intelligent Networks Operation (formerly Eon Systems)"},
{ {0x00, 0x00, 0xC8,0x00,0x00,0x00}, "Altos"},
{ {0x00, 0x00, 0xC9,0x00,0x00,0x00}, "Emulex Terminal Servers, Print Servers"},
{ {0x00, 0x00, 0xCA,0x00,0x00,0x00}, "LANcity Cable Modems (now owned by BayNetworks)"},
{ {0x00, 0x00, 0xCC,0x00,0x00,0x00}, "Densan Co., Ltd."},
{ {0x00, 0x00, 0xCD,0x00,0x00,0x00}, "Industrial Research Limited"},
{ {0x00, 0x00, 0xD0,0x00,0x00,0x00}, "Develcon Electronics, Ltd."},
{ {0x00, 0x00, 0xD1,0x00,0x00,0x00}, "Adaptec, Inc. product"},
{ {0x00, 0x00, 0xD2,0x00,0x00,0x00}, "SBE Inc"},
{ {0x00, 0x00, 0xD3,0x00,0x00,0x00}, "Wang Labs"},
{ {0x00, 0x00, 0xD4,0x00,0x00,0x00}, "PureData"},
{ {0x00, 0x00, 0xD7,0x00,0x00,0x00}, "Dartmouth College (NED Router)"},
{ {0x00, 0x00, 0xD8,0x00,0x00,0x00}, "old Novell NE1000's (before about 1987?) (also 3Com)"},
{ {0x00, 0x00, 0xDD,0x00,0x00,0x00}, "Gould"},
{ {0x00, 0x00, 0xDE,0x00,0x00,0x00}, "Unigraph"},
{ {0x00, 0x00, 0xE1,0x00,0x00,0x00}, "Hitachi (laptop built-in)"},
{ {0x00, 0x00, 0xE2,0x00,0x00,0x00}, "Acer Counterpoint"},
{ {0x00, 0x00, 0xE3,0x00,0x00,0x00}, "Integrated Micro Products Ltd"},
{ {0x00, 0x00, 0xE4,0x00,0x00,0x00}, "mips?"},
{ {0x00, 0x00, 0xE6,0x00,0x00,0x00}, "Aptor Produits De Comm Indust"},
{ {0x00, 0x00, 0xE8,0x00,0x00,0x00}, "Accton Technology Corporation"},
{ {0x00, 0x00, 0xE9,0x00,0x00,0x00}, "ISICAD, Inc."},
{ {0x00, 0x00, 0xED,0x00,0x00,0x00}, "April"},
{ {0x00, 0x00, 0xEE,0x00,0x00,0x00}, "Network Designers Limited [also KNX Ltd, a former division]"},
{ {0x00, 0x00, 0xEF,0x00,0x00,0x00}, "Alantec (now owned by ForeSystems)"},
{ {0x00, 0x00, 0xF0,0x00,0x00,0x00}, "Samsung"},
{ {0x00, 0x00, 0xF2,0x00,0x00,0x00}, "Spider Communications (Montreal, not Spider Systems)"},
{ {0x00, 0x00, 0xF3,0x00,0x00,0x00}, "Gandalf Data Ltd. - Canada"},
{ {0x00, 0x00, 0xF4,0x00,0x00,0x00}, "Allied Telesis, Inc."},
{ {0x00, 0x00, 0xF6,0x00,0x00,0x00}, "A.M.C. (Applied Microsystems Corp.)"},
{ {0x00, 0x00, 0xF8,0x00,0x00,0x00}, "DEC"},
{ {0x00, 0x00, 0xFB,0x00,0x00,0x00}, "Rechner zur Kommunikation"},
{ {0x00, 0x00, 0xFD,0x00,0x00,0x00}, "High Level Hardware (Orion, UK)"},
{ {0x00, 0x00, 0xFF,0x00,0x00,0x00}, "Camtec Electronics (UK) Ltd."},
{ {0x00, 0x01, 0x02,0x00,0x00,0x00}, "BBN (Bolt Beranek and Newman, Inc.) internal usage (not registered)"},
{ {0x00, 0x01, 0x43,0x00,0x00,0x00}, "IEEE 802"},
{ {0x00, 0x01, 0x50,0x00,0x00,0x00}, "Megahertz (now 3com) modem"},
{ {0x00, 0x01, 0x63,0x00,0x00,0x00}, "NDC (National Datacomm Corporation)"},
{ {0x00, 0x01, 0x68,0x00,0x00,0x00}, "W&G (Wandel & Goltermann) [incorrect according to W&G]"},
{ {0x00, 0x01, 0xC8,0x00,0x00,0x00}, "Thomas Conrad Corp."},
{ {0x00, 0x01, 0xFA,0x00,0x00,0x00}, "Compaq (PageMarq printers)"},
{ {0x00, 0x02, 0x04,0x00,0x00,0x00}, "Novell NE3200"},
{ {0x00, 0x02, 0x05,0x00,0x00,0x00}, "Hamilton (Sparc Clones)"},
{ {0x00, 0x02, 0x16,0x00,0x00,0x00}, "ESI (Extended Systems, Inc) print servers"},
{ {0x00, 0x02, 0x88,0x00,0x00,0x00}, "Global Village (PCcard in Mac portable)"},
{ {0x00, 0x03, 0xC6,0x00,0x00,0x00}, "Morning Star Technologies Inc"},
{ {0x00, 0x04, 0x00,0x00,0x00,0x00}, "Lexmark (Print Server)"},
{ {0x00, 0x04, 0xAC,0x00,0x00,0x00}, "IBM PCMCIA Ethernet adapter."},
{ {0x00, 0x05, 0x02,0x00,0x00,0x00}, "Apple (PCI bus Macs)"},
{ {0x00, 0x05, 0x9A,0x00,0x00,0x00}, "PowerComputing (Mac clone)"},
{ {0x00, 0x05, 0xA8,0x00,0x00,0x00}, "PowerComputing Mac clones"},
{ {0x00, 0x06, 0x0D,0x00,0x00,0x00}, "Hewlett-Packard JetDirect token-ring interfaces"},
{ {0x00, 0x06, 0x29,0x00,0x00,0x00}, "IBM RISC6000 system"},
{ {0x00, 0x06, 0x7C,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x06, 0xC1,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x07, 0x01,0x00,0x00,0x00}, "Racal-Datacom"},
{ {0x00, 0x07, 0x0D,0x00,0x00,0x00}, "Cisco 2511 Token Ring"},
{ {0x00, 0x08, 0x52,0x00,0x00,0x00}, "Technically Elite Concepts"},
{ {0x00, 0x08, 0x55,0x00,0x00,0x00}, "Fermilab"},
{ {0x00, 0x08, 0xC7,0x00,0x00,0x00}, "Compaq"},
{ {0x00, 0x10, 0x07,0x00,0x00,0x00}, "Cisco Systems Catalyst 1900"},
{ {0x00, 0x10, 0x0B,0x00,0x00,0x00}, "Cisco Systems"},
{ {0x00, 0x10, 0x0D,0x00,0x00,0x00}, "Cisco Systems Catalyst 2924-XL"},
{ {0x00, 0x10, 0x11,0x00,0x00,0x00}, "Cisco Systems Cisco 75xx"},
{ {0x00, 0x10, 0x1F,0x00,0x00,0x00}, "Cisco Systems Catalyst 2901"},
{ {0x00, 0x10, 0x29,0x00,0x00,0x00}, "Cisco Systems Catalyst 5000"},
{ {0x00, 0x10, 0x2F,0x00,0x00,0x00}, "Cisco Systems Cisco 5000"},
{ {0x00, 0x10, 0x4B,0x00,0x00,0x00}, "3Com 3C905-TX PCI"},
{ {0x00, 0x10, 0x5A,0x00,0x00,0x00}, "3Com Fast Etherlink XL in a Gateway 2000"},
{ {0x00, 0x10, 0x60,0x00,0x00,0x00}, "Billington Novell NE200 Compatible"},
{ {0x00, 0x10, 0x79,0x00,0x00,0x00}, "Cisco 5500 Router"},
{ {0x00, 0x10, 0x7A,0x00,0x00,0x00}, "Ambicom (was Tandy?)"},
{ {0x00, 0x10, 0x7B,0x00,0x00,0x00}, "Cisco Systems"},
{ {0x00, 0x10, 0x83,0x00,0x00,0x00}, "HP-UX E 9000/889"},
{ {0x00, 0x10, 0xA4,0x00,0x00,0x00}, "Xircom RealPort 10/100 PC Card"},
{ {0x00, 0x10, 0xA6,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x10, 0xD7,0x00,0x00,0x00}, "Argosy EN 220 Fast Ethernet PCMCIA"},
{ {0x00, 0x10, 0xF6,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x17, 0x00,0x00,0x00,0x00}, "Kabel"},
{ {0x00, 0x20, 0x00,0x00,0x00,0x00}, "Lexmark (Print Server)"},
{ {0x00, 0x20, 0x05,0x00,0x00,0x00}, "simpletech"},
{ {0x00, 0x20, 0x08,0x00,0x00,0x00}, "Cable & Computer Technology"},
{ {0x00, 0x20, 0x0C,0x00,0x00,0x00}, "Adastra Systems Corp"},
{ {0x00, 0x20, 0x11,0x00,0x00,0x00}, "Canopus Co Ltd"},
{ {0x00, 0x20, 0x17,0x00,0x00,0x00}, "Orbotech"},
{ {0x00, 0x20, 0x18,0x00,0x00,0x00}, "Realtek"},
{ {0x00, 0x20, 0x1A,0x00,0x00,0x00}, "Nbase"},
{ {0x00, 0x20, 0x25,0x00,0x00,0x00}, "Control Technology Inc (Industrial Controls and Network Interfaces)"},
{ {0x00, 0x20, 0x28,0x00,0x00,0x00}, "Bloomberg"},
{ {0x00, 0x20, 0x29,0x00,0x00,0x00}, "TeleProcessing CSU/DSU (now owned by ADC/Kentrox)"},
{ {0x00, 0x20, 0x2B,0x00,0x00,0x00}, "ATML (Advanced Telecommunications Modules, Ltd.)"},
{ {0x00, 0x20, 0x35,0x00,0x00,0x00}, "IBM (International Business Machines) mainframes, Etherjet printers"},
{ {0x00, 0x20, 0x36,0x00,0x00,0x00}, "BMC Software"},
{ {0x00, 0x20, 0x42,0x00,0x00,0x00}, "Datametrics Corp"},
{ {0x00, 0x20, 0x45,0x00,0x00,0x00}, "SolCom Systems Limited"},
{ {0x00, 0x20, 0x48,0x00,0x00,0x00}, "Fore Systems Inc"},
{ {0x00, 0x20, 0x4B,0x00,0x00,0x00}, "Autocomputer Co Ltd"},
{ {0x00, 0x20, 0x4C,0x00,0x00,0x00}, "Mitron Computer Pte Ltd"},
{ {0x00, 0x20, 0x56,0x00,0x00,0x00}, "Neoproducts"},
{ {0x00, 0x20, 0x61,0x00,0x00,0x00}, "Dynatech Communications Inc"},
{ {0x00, 0x20, 0x63,0x00,0x00,0x00}, "Wipro Infotech Ltd"},
{ {0x00, 0x20, 0x66,0x00,0x00,0x00}, "General Magic Inc"},
{ {0x00, 0x20, 0x67,0x00,0x00,0x00}, "Node Runner Inc"},
{ {0x00, 0x20, 0x6B,0x00,0x00,0x00}, "Minolta Co., Ltd Network printers"},
{ {0x00, 0x20, 0x78,0x00,0x00,0x00}, "Runtop Inc"},
{ {0x00, 0x20, 0x85,0x00,0x00,0x00}, "3COM SuperStack II UPS management module"},
{ {0x00, 0x20, 0x8A,0x00,0x00,0x00}, "Sonix Communications Ltd"},
{ {0x00, 0x20, 0x8B,0x00,0x00,0x00}, "Focus Enhancements"},
{ {0x00, 0x20, 0x8C,0x00,0x00,0x00}, "Galaxy Networks Inc"},
{ {0x00, 0x20, 0x94,0x00,0x00,0x00}, "Cubix Corporation"},
{ {0x00, 0x20, 0xA5,0x00,0x00,0x00}, "Newer Technology"},
{ {0x00, 0x20, 0xA6,0x00,0x00,0x00}, "Proxim Inc"},
{ {0x00, 0x20, 0xA7,0x00,0x00,0x00}, "Pairgain Technologies, Inc."},
{ {0x00, 0x20, 0xAF,0x00,0x00,0x00}, "3COM Corporation"},
{ {0x00, 0x20, 0xB2,0x00,0x00,0x00}, "CSP (Printline Multiconnectivity converter)"},
{ {0x00, 0x20, 0xB6,0x00,0x00,0x00}, "Agile Networks Inc"},
{ {0x00, 0x20, 0xB9,0x00,0x00,0x00}, "Metricom, Inc."},
{ {0x00, 0x20, 0xC5,0x00,0x00,0x00}, "Eagle NE2000"},
{ {0x00, 0x20, 0xC6,0x00,0x00,0x00}, "NECTEC"},
{ {0x00, 0x20, 0xD0,0x00,0x00,0x00}, "Versalynx Corp. The One Port terminal server"},
{ {0x00, 0x20, 0xD2,0x00,0x00,0x00}, "RAD Data Communications Ltd"},
{ {0x00, 0x20, 0xD3,0x00,0x00,0x00}, "OST (Ouet Standard Telematique)"},
{ {0x00, 0x20, 0xD8,0x00,0x00,0x00}, "NetWave"},
{ {0x00, 0x20, 0xDA,0x00,0x00,0x00}, "Xylan"},
{ {0x00, 0x20, 0xDC,0x00,0x00,0x00}, "Densitron Taiwan Ltd"},
{ {0x00, 0x20, 0xE0,0x00,0x00,0x00}, "PreMax PE-200 (PCMCIA NE2000-clone card, sold by InfoExpress)"},
{ {0x00, 0x20, 0xE5,0x00,0x00,0x00}, "Apex Data"},
{ {0x00, 0x20, 0xEE,0x00,0x00,0x00}, "Gtech Corporation"},
{ {0x00, 0x20, 0xF6,0x00,0x00,0x00}, "Net Tek & Karlnet Inc"},
{ {0x00, 0x20, 0xF8,0x00,0x00,0x00}, "Carrera Computers Inc"},
{ {0x00, 0x20, 0xFC,0x00,0x00,0x00}, "Matrox"},
{ {0x00, 0x40, 0x01,0x00,0x00,0x00}, "Zero One Technology Co Ltd (ZyXEL?)"},
{ {0x00, 0x40, 0x05,0x00,0x00,0x00}, "TRENDware International Inc.; Linksys; Simple Net; all three reported"},
{ {0x00, 0x40, 0x09,0x00,0x00,0x00}, "Tachibana Tectron Co Ltd"},
{ {0x00, 0x40, 0x0B,0x00,0x00,0x00}, "Crescendo (now owned by Cisco)"},
{ {0x00, 0x40, 0x0C,0x00,0x00,0x00}, "General Micro Systems, Inc."},
{ {0x00, 0x40, 0x0D,0x00,0x00,0x00}, "LANNET Data Communications"},
{ {0x00, 0x40, 0x10,0x00,0x00,0x00}, "Sonic Mac Ethernet interfaces"},
{ {0x00, 0x40, 0x11,0x00,0x00,0x00}, "Facilities Andover Environmental Controllers"},
{ {0x00, 0x40, 0x13,0x00,0x00,0x00}, "NTT Data Communication Systems Corp"},
{ {0x00, 0x40, 0x14,0x00,0x00,0x00}, "Comsoft Gmbh"},
{ {0x00, 0x40, 0x15,0x00,0x00,0x00}, "Ascom"},
{ {0x00, 0x40, 0x17,0x00,0x00,0x00}, "XCd XJet - HP printer server card"},
{ {0x00, 0x40, 0x1C,0x00,0x00,0x00}, "AST Pentium/90 PC (emulating AMD EISA card)"},
{ {0x00, 0x40, 0x1F,0x00,0x00,0x00}, "Colorgraph Ltd"},
{ {0x00, 0x40, 0x20,0x00,0x00,0x00}, "Pilkington Communication"},
{ {0x00, 0x40, 0x23,0x00,0x00,0x00}, "Logic Corporation"},
{ {0x00, 0x40, 0x25,0x00,0x00,0x00}, "Molecular Dynamics"},
{ {0x00, 0x40, 0x26,0x00,0x00,0x00}, "Melco Inc"},
{ {0x00, 0x40, 0x27,0x00,0x00,0x00}, "SMC Massachusetts"},
{ {0x00, 0x40, 0x28,0x00,0x00,0x00}, "Netcomm"},
{ {0x00, 0x40, 0x2A,0x00,0x00,0x00}, "Canoga-Perkins"},
{ {0x00, 0x40, 0x2B,0x00,0x00,0x00}, "TriGem"},
{ {0x00, 0x40, 0x2F,0x00,0x00,0x00}, "Xlnt Designs Inc (XDI)"},
{ {0x00, 0x40, 0x30,0x00,0x00,0x00}, "GK Computer"},
{ {0x00, 0x40, 0x32,0x00,0x00,0x00}, "Digital Communications"},
{ {0x00, 0x40, 0x33,0x00,0x00,0x00}, "Addtron Technology Co., Ltd."},
{ {0x00, 0x40, 0x36,0x00,0x00,0x00}, "TribeStar"},
{ {0x00, 0x40, 0x39,0x00,0x00,0x00}, "Optec Daiichi Denko Co Ltd"},
{ {0x00, 0x40, 0x3C,0x00,0x00,0x00}, "Forks, Inc."},
{ {0x00, 0x40, 0x41,0x00,0x00,0x00}, "Fujikura Ltd."},
{ {0x00, 0x40, 0x43,0x00,0x00,0x00}, "Nokia Data Communications"},
{ {0x00, 0x40, 0x48,0x00,0x00,0x00}, "SMD Informatica S.A."},
{ {0x00, 0x40, 0x4C,0x00,0x00,0x00}, "Hypertec Pty Ltd."},
{ {0x00, 0x40, 0x4D,0x00,0x00,0x00}, "Telecomm Techniques"},
{ {0x00, 0x40, 0x4F,0x00,0x00,0x00}, "Space & Naval Warfare Systems"},
{ {0x00, 0x40, 0x50,0x00,0x00,0x00}, "Ironics, Incorporated"},
{ {0x00, 0x40, 0x52,0x00,0x00,0x00}, "Star Technologies Inc"},
{ {0x00, 0x40, 0x53,0x00,0x00,0x00}, "Datum [Bancomm Division] TymServe 2000"},
{ {0x00, 0x40, 0x54,0x00,0x00,0x00}, "Thinking Machines Corporation"},
{ {0x00, 0x40, 0x57,0x00,0x00,0x00}, "Lockheed-Sanders"},
{ {0x00, 0x40, 0x59,0x00,0x00,0x00}, "Yoshida Kogyo K.K."},
{ {0x00, 0x40, 0x5B,0x00,0x00,0x00}, "Funasset Limited"},
{ {0x00, 0x40, 0x5D,0x00,0x00,0x00}, "Star-Tek Inc"},
{ {0x00, 0x40, 0x66,0x00,0x00,0x00}, "Hitachi Cable, Ltd."},
{ {0x00, 0x40, 0x67,0x00,0x00,0x00}, "Omnibyte Corporation"},
{ {0x00, 0x40, 0x68,0x00,0x00,0x00}, "Extended Systems"},
{ {0x00, 0x40, 0x69,0x00,0x00,0x00}, "Lemcom Systems Inc"},
{ {0x00, 0x40, 0x6A,0x00,0x00,0x00}, "Kentek Information Systems Inc"},
{ {0x00, 0x40, 0x6E,0x00,0x00,0x00}, "Corollary, Inc."},
{ {0x00, 0x40, 0x6F,0x00,0x00,0x00}, "Sync Research Inc"},
{ {0x00, 0x40, 0x72,0x00,0x00,0x00}, "Applied Innovation"},
{ {0x00, 0x40, 0x74,0x00,0x00,0x00}, "Cable and Wireless"},
{ {0x00, 0x40, 0x76,0x00,0x00,0x00}, "AMP Incorporated"},
{ {0x00, 0x40, 0x78,0x00,0x00,0x00}, "Wearnes Automation Pte Ltd"},
{ {0x00, 0x40, 0x7F,0x00,0x00,0x00}, "Agema Infrared Systems AB"},
{ {0x00, 0x40, 0x82,0x00,0x00,0x00}, "Laboratory Equipment Corp"},
{ {0x00, 0x40, 0x85,0x00,0x00,0x00}, "SAAB Instruments AB"},
{ {0x00, 0x40, 0x86,0x00,0x00,0x00}, "Michels & Kleberhoff Computer"},
{ {0x00, 0x40, 0x87,0x00,0x00,0x00}, "Ubitrex Corporation"},
{ {0x00, 0x40, 0x88,0x00,0x00,0x00}, "Mobuis NuBus (Mac) combination video/EtherTalk"},
{ {0x00, 0x40, 0x8A,0x00,0x00,0x00}, "TPS Teleprocessing Sys. Gmbh"},
{ {0x00, 0x40, 0x8C,0x00,0x00,0x00}, "Axis Communications AB"},
{ {0x00, 0x40, 0x8E,0x00,0x00,0x00}, "CXR/Digilog"},
{ {0x00, 0x40, 0x8F,0x00,0x00,0x00}, "WM-Data Minfo AB"},
{ {0x00, 0x40, 0x90,0x00,0x00,0x00}, "Ansel Communications PC NE2000 compatible twisted-pair ethernet cards"},
{ {0x00, 0x40, 0x91,0x00,0x00,0x00}, "Procomp Industria Eletronica"},
{ {0x00, 0x40, 0x92,0x00,0x00,0x00}, "ASP Computer Products, Inc."},
{ {0x00, 0x40, 0x94,0x00,0x00,0x00}, "Shographics Inc"},
{ {0x00, 0x40, 0x95,0x00,0x00,0x00}, "Eagle Technologies [UMC also reported]"},
{ {0x00, 0x40, 0x96,0x00,0x00,0x00}, "Telesystems SLW Inc"},
{ {0x00, 0x40, 0x9A,0x00,0x00,0x00}, "Network Express Inc"},
{ {0x00, 0x40, 0x9C,0x00,0x00,0x00}, "Transware"},
{ {0x00, 0x40, 0x9D,0x00,0x00,0x00}, "DigiBoard Ethernet-ISDN bridges"},
{ {0x00, 0x40, 0x9E,0x00,0x00,0x00}, "Concurrent Technologies Ltd."},
{ {0x00, 0x40, 0x9F,0x00,0x00,0x00}, "Lancast/Casat Technology Inc"},
{ {0x00, 0x40, 0xA4,0x00,0x00,0x00}, "Rose Electronics"},
{ {0x00, 0x40, 0xA6,0x00,0x00,0x00}, "Cray Research Inc."},
{ {0x00, 0x40, 0xAA,0x00,0x00,0x00}, "Valmet Automation Inc"},
{ {0x00, 0x40, 0xAD,0x00,0x00,0x00}, "SMA Regelsysteme Gmbh"},
{ {0x00, 0x40, 0xAE,0x00,0x00,0x00}, "Delta Controls, Inc."},
{ {0x00, 0x40, 0xAF,0x00,0x00,0x00}, "Digital Products, Inc. (DPI)."},
{ {0x00, 0x40, 0xB4,0x00,0x00,0x00}, "3COM K.K."},
{ {0x00, 0x40, 0xB5,0x00,0x00,0x00}, "Video Technology Computers Ltd"},
{ {0x00, 0x40, 0xB6,0x00,0x00,0x00}, "Computerm Corporation"},
{ {0x00, 0x40, 0xB9,0x00,0x00,0x00}, "MACQ Electronique SA"},
{ {0x00, 0x40, 0xBD,0x00,0x00,0x00}, "Starlight Networks Inc"},
{ {0x00, 0x40, 0xC1,0x00,0x00,0x00}, "Bizerba-Werke Wilheim Kraut"},
{ {0x00, 0x40, 0xC2,0x00,0x00,0x00}, "Applied Computing Devices"},
{ {0x00, 0x40, 0xC3,0x00,0x00,0x00}, "Fischer and Porter Co."},
{ {0x00, 0x40, 0xC5,0x00,0x00,0x00}, "Micom Communications Corp."},
{ {0x00, 0x40, 0xC6,0x00,0x00,0x00}, "Fibernet Research, Inc."},
{ {0x00, 0x40, 0xC7,0x00,0x00,0x00}, "Danpex Corporation"},
{ {0x00, 0x40, 0xC8,0x00,0x00,0x00}, "Milan Technology Corp."},
{ {0x00, 0x40, 0xCC,0x00,0x00,0x00}, "Silcom Manufacturing Technology Inc"},
{ {0x00, 0x40, 0xCF,0x00,0x00,0x00}, "Strawberry Tree Inc"},
{ {0x00, 0x40, 0xD0,0x00,0x00,0x00}, "DEC/Compaq"},
{ {0x00, 0x40, 0xD2,0x00,0x00,0x00}, "Pagine Corporation"},
{ {0x00, 0x40, 0xD4,0x00,0x00,0x00}, "Gage Talker Corp."},
{ {0x00, 0x40, 0xD7,0x00,0x00,0x00}, "Studio Gen Inc"},
{ {0x00, 0x40, 0xD8,0x00,0x00,0x00}, "Ocean Office Automation Ltd"},
{ {0x00, 0x40, 0xDC,0x00,0x00,0x00}, "Tritec Electronic Gmbh"},
{ {0x00, 0x40, 0xDF,0x00,0x00,0x00}, "Digalog Systems, Inc."},
{ {0x00, 0x40, 0xE1,0x00,0x00,0x00}, "Marner International Inc"},
{ {0x00, 0x40, 0xE2,0x00,0x00,0x00}, "Mesa Ridge Technologies Inc"},
{ {0x00, 0x40, 0xE3,0x00,0x00,0x00}, "Quin Systems Ltd"},
{ {0x00, 0x40, 0xE5,0x00,0x00,0x00}, "Sybus Corporation"},
{ {0x00, 0x40, 0xE7,0x00,0x00,0x00}, "Arnos Instruments & Computer"},
{ {0x00, 0x40, 0xE9,0x00,0x00,0x00}, "Accord Systems, Inc."},
{ {0x00, 0x40, 0xEA,0x00,0x00,0x00}, "PlainTree Systems Inc"},
{ {0x00, 0x40, 0xED,0x00,0x00,0x00}, "Network Controls International Inc"},
{ {0x00, 0x40, 0xF0,0x00,0x00,0x00}, "Micro Systems Inc"},
{ {0x00, 0x40, 0xF1,0x00,0x00,0x00}, "Chuo Electronics Co., Ltd."},
{ {0x00, 0x40, 0xF4,0x00,0x00,0x00}, "Cameo Communications, Inc."},
{ {0x00, 0x40, 0xF5,0x00,0x00,0x00}, "OEM Engines"},
{ {0x00, 0x40, 0xF6,0x00,0x00,0x00}, "Katron Computers Inc"},
{ {0x00, 0x40, 0xF9,0x00,0x00,0x00}, "Combinet"},
{ {0x00, 0x40, 0xFA,0x00,0x00,0x00}, "Microboards Inc"},
{ {0x00, 0x40, 0xFB,0x00,0x00,0x00}, "Cascade Communications Corp."},
{ {0x00, 0x40, 0xFD,0x00,0x00,0x00}, "LXE"},
{ {0x00, 0x40, 0xFF,0x00,0x00,0x00}, "Telebit Corporation Personal NetBlazer"},
{ {0x00, 0x48, 0x54,0x00,0x00,0x00}, "Digital SemiConductor 21143/2 based 10/100"},
{ {0x00, 0x4F, 0x49,0x00,0x00,0x00}, "Realtek"},
{ {0x00, 0x4F, 0x4B,0x00,0x00,0x00}, "Pine Technology Ltd."},
{ {0x00, 0x50, 0x04,0x00,0x00,0x00}, "3com 3C90X"},
{ {0x00, 0x50, 0x0F,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x50, 0x4D,0x00,0x00,0x00}, "Repotec Group"},
{ {0x00, 0x50, 0x4E,0x00,0x00,0x00}, "UMC UM9008 NE2000-compatible ISA Card for PC"},
{ {0x00, 0x50, 0x50,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x50, 0x69,0x00,0x00,0x00}, "PixStream Incorporated"},
{ {0x00, 0x50, 0xBD,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x50, 0xE2,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x55, 0x00,0x00,0x00,0x00}, "Xerox"},
{ {0x00, 0x60, 0x08,0x00,0x00,0x00}, "3Com 3Com PCI form factor 3C905 TX board"},
{ {0x00, 0x60, 0x09,0x00,0x00,0x00}, "Cisco Catalyst 5000 Ethernet switch"},
{ {0x00, 0x60, 0x25,0x00,0x00,0x00}, "Active Imaging Inc."},
{ {0x00, 0x60, 0x2F,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x60, 0x30,0x00,0x00,0x00}, "VillageTronic used on Amiga"},
{ {0x00, 0x60, 0x3E,0x00,0x00,0x00}, "Cisco 100Mbps interface"},
{ {0x00, 0x60, 0x47,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x60, 0x4E,0x00,0x00,0x00}, "Cycle Computer (Sun MotherBoard Replacements)"},
{ {0x00, 0x60, 0x52,0x00,0x00,0x00}, "Realtek (RTL 8029 == PCI NE2000)"},
{ {0x00, 0x60, 0x5C,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x60, 0x67,0x00,0x00,0x00}, "Acer Lan"},
{ {0x00, 0x60, 0x70,0x00,0x00,0x00}, "Cisco routers (2524 and 4500)"},
{ {0x00, 0x60, 0x83,0x00,0x00,0x00}, "Cisco Systems, Inc. 3620/3640 routers"},
{ {0x00, 0x60, 0x8C,0x00,0x00,0x00}, "3Com (1990 onwards)"},
{ {0x00, 0x60, 0x94,0x00,0x00,0x00}, "AMD PCNET PCI"},
{ {0x00, 0x60, 0x97,0x00,0x00,0x00}, "3Com"},
{ {0x00, 0x60, 0xB0,0x00,0x00,0x00}, "Hewlett-Packard"},
{ {0x00, 0x60, 0xF5,0x00,0x00,0x00}, "Phobos FastEthernet for Unix WS"},
{ {0x00, 0x80, 0x00,0x00,0x00,0x00}, "Multitech Systems Inc"},
{ {0x00, 0x80, 0x01,0x00,0x00,0x00}, "Periphonics Corporation"},
{ {0x00, 0x80, 0x04,0x00,0x00,0x00}, "Antlow Computers, Ltd."},
{ {0x00, 0x80, 0x05,0x00,0x00,0x00}, "Cactus Computer Inc."},
{ {0x00, 0x80, 0x06,0x00,0x00,0x00}, "Compuadd Corporation"},
{ {0x00, 0x80, 0x07,0x00,0x00,0x00}, "Dlog NC-Systeme"},
{ {0x00, 0x80, 0x09,0x00,0x00,0x00}, "Jupiter Systems (older MX-600 series machines)"},
{ {0x00, 0x80, 0x0D,0x00,0x00,0x00}, "Vosswinkel FU"},
{ {0x00, 0x80, 0x0F,0x00,0x00,0x00}, "SMC (Standard Microsystem Corp.)"},
{ {0x00, 0x80, 0x10,0x00,0x00,0x00}, "Commodore"},
{ {0x00, 0x80, 0x12,0x00,0x00,0x00}, "IMS Corp. IMS failure analysis tester"},
{ {0x00, 0x80, 0x13,0x00,0x00,0x00}, "Thomas Conrad Corp."},
{ {0x00, 0x80, 0x15,0x00,0x00,0x00}, "Seiko Systems Inc"},
{ {0x00, 0x80, 0x16,0x00,0x00,0x00}, "Wandel & Goltermann"},
{ {0x00, 0x80, 0x17,0x00,0x00,0x00}, "PFU"},
{ {0x00, 0x80, 0x19,0x00,0x00,0x00}, "Dayna Communications Etherprint product"},
{ {0x00, 0x80, 0x1A,0x00,0x00,0x00}, "Bell Atlantic"},
{ {0x00, 0x80, 0x1B,0x00,0x00,0x00}, "Kodiak Technology"},
{ {0x00, 0x80, 0x1C,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x80, 0x21,0x00,0x00,0x00}, "Newbridge Networks Corporation"},
{ {0x00, 0x80, 0x23,0x00,0x00,0x00}, "Integrated Business Networks"},
{ {0x00, 0x80, 0x24,0x00,0x00,0x00}, "Kalpana"},
{ {0x00, 0x80, 0x26,0x00,0x00,0x00}, "Network Products Corporation"},
{ {0x00, 0x80, 0x29,0x00,0x00,0x00}, "Microdyne Corporation"},
{ {0x00, 0x80, 0x2A,0x00,0x00,0x00}, "Test Systems & Simulations Inc"},
{ {0x00, 0x80, 0x2C,0x00,0x00,0x00}, "The Sage Group PLC"},
{ {0x00, 0x80, 0x2D,0x00,0x00,0x00}, "Xylogics, Inc. Annex terminal servers"},
{ {0x00, 0x80, 0x2E,0x00,0x00,0x00}, "Plexcom, Inc."},
{ {0x00, 0x80, 0x33,0x00,0x00,0x00}, "Formation (?)"},
{ {0x00, 0x80, 0x34,0x00,0x00,0x00}, "SMT-Goupil"},
{ {0x00, 0x80, 0x35,0x00,0x00,0x00}, "Technology Works"},
{ {0x00, 0x80, 0x37,0x00,0x00,0x00}, "Ericsson Business Comm."},
{ {0x00, 0x80, 0x38,0x00,0x00,0x00}, "Data Research & Applications"},
{ {0x00, 0x80, 0x3B,0x00,0x00,0x00}, "APT Communications, Inc."},
{ {0x00, 0x80, 0x3D,0x00,0x00,0x00}, "Surigiken Co Ltd"},
{ {0x00, 0x80, 0x3E,0x00,0x00,0x00}, "Synernetics"},
{ {0x00, 0x80, 0x3F,0x00,0x00,0x00}, "Hyundai Electronics"},
{ {0x00, 0x80, 0x42,0x00,0x00,0x00}, "Force Computers"},
{ {0x00, 0x80, 0x43,0x00,0x00,0x00}, "Networld Inc"},
{ {0x00, 0x80, 0x45,0x00,0x00,0x00}, "Matsushita Electric Ind Co"},
{ {0x00, 0x80, 0x46,0x00,0x00,0x00}, "University of Toronto"},
{ {0x00, 0x80, 0x48,0x00,0x00,0x00}, "Compex, used by Commodore and DEC at least"},
{ {0x00, 0x80, 0x49,0x00,0x00,0x00}, "Nissin Electric Co Ltd"},
{ {0x00, 0x80, 0x4C,0x00,0x00,0x00}, "Contec Co., Ltd."},
{ {0x00, 0x80, 0x4D,0x00,0x00,0x00}, "Cyclone Microsystems, Inc."},
{ {0x00, 0x80, 0x51,0x00,0x00,0x00}, "ADC Fibermux"},
{ {0x00, 0x80, 0x52,0x00,0x00,0x00}, "Network Professor"},
{ {0x00, 0x80, 0x57,0x00,0x00,0x00}, "Adsoft Ltd"},
{ {0x00, 0x80, 0x5A,0x00,0x00,0x00}, "Tulip Computers International BV"},
{ {0x00, 0x80, 0x5B,0x00,0x00,0x00}, "Condor Systems, Inc."},
{ {0x00, 0x80, 0x5C,0x00,0x00,0x00}, "Agilis(?)"},
{ {0x00, 0x80, 0x5F,0x00,0x00,0x00}, "Compaq Computer Corporation"},
{ {0x00, 0x80, 0x60,0x00,0x00,0x00}, "Network Interface Corporation"},
{ {0x00, 0x80, 0x62,0x00,0x00,0x00}, "Interface Co."},
{ {0x00, 0x80, 0x63,0x00,0x00,0x00}, "Richard Hirschmann Gmbh & Co"},
{ {0x00, 0x80, 0x64,0x00,0x00,0x00}, "Wyse"},
{ {0x00, 0x80, 0x67,0x00,0x00,0x00}, "Square D Company"},
{ {0x00, 0x80, 0x69,0x00,0x00,0x00}, "Computone Systems"},
{ {0x00, 0x80, 0x6A,0x00,0x00,0x00}, "ERI (Empac Research Inc.)"},
{ {0x00, 0x80, 0x6B,0x00,0x00,0x00}, "Schmid Telecommunication"},
{ {0x00, 0x80, 0x6C,0x00,0x00,0x00}, "Cegelec Projects Ltd"},
{ {0x00, 0x80, 0x6D,0x00,0x00,0x00}, "Century Systems Corp."},
{ {0x00, 0x80, 0x6E,0x00,0x00,0x00}, "Nippon Steel Corporation"},
{ {0x00, 0x80, 0x6F,0x00,0x00,0x00}, "Onelan Ltd"},
{ {0x00, 0x80, 0x71,0x00,0x00,0x00}, "SAI Technology"},
{ {0x00, 0x80, 0x72,0x00,0x00,0x00}, "Microplex Systems Ltd"},
{ {0x00, 0x80, 0x74,0x00,0x00,0x00}, "Fisher Controls"},
{ {0x00, 0x80, 0x79,0x00,0x00,0x00}, "Microbus Designs Ltd"},
{ {0x00, 0x80, 0x7B,0x00,0x00,0x00}, "Artel Communications Corp."},
{ {0x00, 0x80, 0x7C,0x00,0x00,0x00}, "FiberCom"},
{ {0x00, 0x80, 0x7D,0x00,0x00,0x00}, "Equinox Systems Inc"},
{ {0x00, 0x80, 0x82,0x00,0x00,0x00}, "PEP Modular Computers Gmbh"},
{ {0x00, 0x80, 0x86,0x00,0x00,0x00}, "Computer Generation Inc."},
{ {0x00, 0x80, 0x87,0x00,0x00,0x00}, "Okidata"},
{ {0x00, 0x80, 0x8A,0x00,0x00,0x00}, "Summit (?)"},
{ {0x00, 0x80, 0x8B,0x00,0x00,0x00}, "Dacoll Limited"},
{ {0x00, 0x80, 0x8C,0x00,0x00,0x00}, "Netscout Systems (formerly Frontier Software Development)"},
{ {0x00, 0x80, 0x8D,0x00,0x00,0x00}, "Westcove Technology BV"},
{ {0x00, 0x80, 0x8E,0x00,0x00,0x00}, "Radstone Technology"},
{ {0x00, 0x80, 0x90,0x00,0x00,0x00}, "Microtek International Inc"},
{ {0x00, 0x80, 0x92,0x00,0x00,0x00}, "Japan Computer Industry, Inc."},
{ {0x00, 0x80, 0x93,0x00,0x00,0x00}, "Xyron Corporation"},
{ {0x00, 0x80, 0x94,0x00,0x00,0x00}, "Sattcontrol AB"},
{ {0x00, 0x80, 0x96,0x00,0x00,0x00}, "HDS (Human Designed Systems) X terminals"},
{ {0x00, 0x80, 0x98,0x00,0x00,0x00}, "TDK Corporation"},
{ {0x00, 0x80, 0x9A,0x00,0x00,0x00}, "Novus Networks Ltd"},
{ {0x00, 0x80, 0x9B,0x00,0x00,0x00}, "Justsystem Corporation"},
{ {0x00, 0x80, 0x9D,0x00,0x00,0x00}, "Datacraft Manufactur'g Pty Ltd"},
{ {0x00, 0x80, 0x9F,0x00,0x00,0x00}, "Alcatel Business Systems"},
{ {0x00, 0x80, 0xA1,0x00,0x00,0x00}, "Microtest"},
{ {0x00, 0x80, 0xA3,0x00,0x00,0x00}, "Lantronix (see also 0800A3)"},
{ {0x00, 0x80, 0xA6,0x00,0x00,0x00}, "Republic Technology Inc"},
{ {0x00, 0x80, 0xA7,0x00,0x00,0x00}, "Measurex Corp"},
{ {0x00, 0x80, 0xAD,0x00,0x00,0x00}, "CNet Technology Used by Telebit (among others)"},
{ {0x00, 0x80, 0xAE,0x00,0x00,0x00}, "Hughes Network Systems"},
{ {0x00, 0x80, 0xAF,0x00,0x00,0x00}, "Allumer Co., Ltd."},
{ {0x00, 0x80, 0xB1,0x00,0x00,0x00}, "Softcom A/S"},
{ {0x00, 0x80, 0xB2,0x00,0x00,0x00}, "NET (Network Equipment Technologies)"},
{ {0x00, 0x80, 0xB6,0x00,0x00,0x00}, "Themis corporation"},
{ {0x00, 0x80, 0xBA,0x00,0x00,0x00}, "Specialix (Asia) Pte Ltd"},
{ {0x00, 0x80, 0xC0,0x00,0x00,0x00}, "Penril Datability Networks"},
{ {0x00, 0x80, 0xC2,0x00,0x00,0x00}, "IEEE 802.1 Committee"},
{ {0x00, 0x80, 0xC6,0x00,0x00,0x00}, "Soho"},
{ {0x00, 0x80, 0xC7,0x00,0x00,0x00}, "Xircom, Inc."},
{ {0x00, 0x80, 0xC8,0x00,0x00,0x00}, "D-Link (also Solectek Pocket Adapters, and LinkSys PCMCIA)"},
{ {0x00, 0x80, 0xC9,0x00,0x00,0x00}, "Alberta Microelectronic Centre"},
{ {0x00, 0x80, 0xCE,0x00,0x00,0x00}, "Broadcast Television Systems"},
{ {0x00, 0x80, 0xD0,0x00,0x00,0x00}, "Computer Products International"},
{ {0x00, 0x80, 0xD3,0x00,0x00,0x00}, "Shiva Appletalk-Ethernet interface"},
{ {0x00, 0x80, 0xD4,0x00,0x00,0x00}, "Chase Limited"},
{ {0x00, 0x80, 0xD6,0x00,0x00,0x00}, "Apple Mac Portable(?)"},
{ {0x00, 0x80, 0xD7,0x00,0x00,0x00}, "Fantum Electronics"},
{ {0x00, 0x80, 0xD8,0x00,0x00,0x00}, "Network Peripherals"},
{ {0x00, 0x80, 0xDA,0x00,0x00,0x00}, "Bruel & Kjaer"},
{ {0x00, 0x80, 0xE0,0x00,0x00,0x00}, "XTP Systems Inc"},
{ {0x00, 0x80, 0xE3,0x00,0x00,0x00}, "Coral (?)"},
{ {0x00, 0x80, 0xE7,0x00,0x00,0x00}, "Lynwood Scientific Dev Ltd"},
{ {0x00, 0x80, 0xEA,0x00,0x00,0x00}, "The Fiber Company"},
{ {0x00, 0x80, 0xF0,0x00,0x00,0x00}, "Kyushu Matsushita Electric Co"},
{ {0x00, 0x80, 0xF1,0x00,0x00,0x00}, "Opus"},
{ {0x00, 0x80, 0xF3,0x00,0x00,0x00}, "Sun Electronics Corp"},
{ {0x00, 0x80, 0xF4,0x00,0x00,0x00}, "Telemechanique Electrique"},
{ {0x00, 0x80, 0xF5,0x00,0x00,0x00}, "Quantel Ltd"},
{ {0x00, 0x80, 0xF7,0x00,0x00,0x00}, "Zenith Communications Products"},
{ {0x00, 0x80, 0xFB,0x00,0x00,0x00}, "BVM Limited"},
{ {0x00, 0x80, 0xFE,0x00,0x00,0x00}, "Azure Technologies Inc"},
{ {0x00, 0x90, 0x04,0x00,0x00,0x00}, "3Com"},
{ {0x00, 0x90, 0x27,0x00,0x00,0x00}, "Intel"},
{ {0x00, 0x90, 0xB1,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x90, 0x2B,0x00,0x00,0x00}, "Cisco Ethernet Switches and Light Streams"},
{ {0x00, 0x90, 0x86,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x90, 0x92,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x90, 0xAB,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x90, 0xB1,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0x90, 0xF2,0x00,0x00,0x00}, "Cisco Ethernet Switches and Light Streams"},
{ {0x00, 0xA0, 0x00,0x00,0x00,0x00}, "Bay Networks Ethernet switch"},
{ {0x00, 0xA0, 0x0C,0x00,0x00,0x00}, "Kingmax Technology Inc. PCMCIA card"},
{ {0x00, 0xA0, 0x24,0x00,0x00,0x00}, "3com"},
{ {0x00, 0xA0, 0x40,0x00,0x00,0x00}, "Apple (PCI Mac)"},
{ {0x00, 0xA0, 0x4B,0x00,0x00,0x00}, "Sonic Systems Inc. EtherFE 10/100 PCI for Mac or PC"},
{ {0x00, 0xA0, 0x73,0x00,0x00,0x00}, "Com21"},
{ {0x00, 0xA0, 0x83,0x00,0x00,0x00}, "Intel"},
{ {0x00, 0xA0, 0x92,0x00,0x00,0x00}, "Intermate International [LAN printer interfaces]"},
{ {0x00, 0xA0, 0xAE,0x00,0x00,0x00}, "Network Peripherals, Inc."},
{ {0x00, 0xA0, 0xC8,0x00,0x00,0x00}, "Adtran, Inc."},
{ {0x00, 0xA0, 0xC9,0x00,0x00,0x00}, "Intel (PRO100B and PRO100+) [used on Cisco PIX firewall among others]"},
{ {0x00, 0xA0, 0xCC,0x00,0x00,0x00}, "Lite-On (used by MacSense in Adapter for Mac, also seen in PCs)"},
{ {0x00, 0xA0, 0xD1,0x00,0x00,0x00}, "National Semiconductor [COMPAQ Docking Station]"},
{ {0x00, 0xA0, 0xD2,0x00,0x00,0x00}, "Allied Telesyn"},
{ {0x00, 0xAA, 0x00,0x00,0x00,0x00}, "Intel"},
{ {0x00, 0xB0, 0xD0,0x00,0x00,0x00}, "Computer Products International"},
{ {0x00, 0xC0, 0x00,0x00,0x00,0x00}, "Lanoptics Ltd"},
{ {0x00, 0xC0, 0x01,0x00,0x00,0x00}, "Diatek Patient Managment"},
{ {0x00, 0xC0, 0x02,0x00,0x00,0x00}, "Sercomm Corporation"},
{ {0x00, 0xC0, 0x03,0x00,0x00,0x00}, "Globalnet Communications"},
{ {0x00, 0xC0, 0x04,0x00,0x00,0x00}, "Japan Business Computer Co.Ltd"},
{ {0x00, 0xC0, 0x05,0x00,0x00,0x00}, "Livingston Enterprises Inc Portmaster (OEMed by Cayman)"},
{ {0x00, 0xC0, 0x06,0x00,0x00,0x00}, "Nippon Avionics Co Ltd"},
{ {0x00, 0xC0, 0x07,0x00,0x00,0x00}, "Pinnacle Data Systems Inc"},
{ {0x00, 0xC0, 0x08,0x00,0x00,0x00}, "Seco SRL"},
{ {0x00, 0xC0, 0x09,0x00,0x00,0x00}, "KT Technology (s) Pte Inc"},
{ {0x00, 0xC0, 0x0A,0x00,0x00,0x00}, "Micro Craft"},
{ {0x00, 0xC0, 0x0B,0x00,0x00,0x00}, "Norcontrol A.S."},
{ {0x00, 0xC0, 0x0C,0x00,0x00,0x00}, "ARK PC Technology, Inc."},
{ {0x00, 0xC0, 0x0D,0x00,0x00,0x00}, "Advanced Logic Research Inc"},
{ {0x00, 0xC0, 0x0E,0x00,0x00,0x00}, "Psitech Inc"},
{ {0x00, 0xC0, 0x0F,0x00,0x00,0x00}, "QNX Software Systems Ltd. [also Quantum Software Systems Ltd]"},
{ {0x00, 0xC0, 0x11,0x00,0x00,0x00}, "Interactive Computing Devices"},
{ {0x00, 0xC0, 0x12,0x00,0x00,0x00}, "Netspan Corp"},
{ {0x00, 0xC0, 0x13,0x00,0x00,0x00}, "Netrix"},
{ {0x00, 0xC0, 0x14,0x00,0x00,0x00}, "Telematics Calabasas"},
{ {0x00, 0xC0, 0x15,0x00,0x00,0x00}, "New Media Corp"},
{ {0x00, 0xC0, 0x16,0x00,0x00,0x00}, "Electronic Theatre Controls"},
{ {0x00, 0xC0, 0x17,0x00,0x00,0x00}, "Fluke"},
{ {0x00, 0xC0, 0x18,0x00,0x00,0x00}, "Lanart Corp"},
{ {0x00, 0xC0, 0x1A,0x00,0x00,0x00}, "Corometrics Medical Systems"},
{ {0x00, 0xC0, 0x1B,0x00,0x00,0x00}, "Socket Communications"},
{ {0x00, 0xC0, 0x1C,0x00,0x00,0x00}, "Interlink Communications Ltd."},
{ {0x00, 0xC0, 0x1D,0x00,0x00,0x00}, "Grand Junction Networks, Inc. (Cisco Catalyst also reported)"},
{ {0x00, 0xC0, 0x1F,0x00,0x00,0x00}, "S.E.R.C.E.L."},
{ {0x00, 0xC0, 0x20,0x00,0x00,0x00}, "Arco Electronic, Control Ltd."},
{ {0x00, 0xC0, 0x21,0x00,0x00,0x00}, "Netexpress"},
{ {0x00, 0xC0, 0x23,0x00,0x00,0x00}, "Tutankhamon Electronics"},
{ {0x00, 0xC0, 0x24,0x00,0x00,0x00}, "Eden Sistemas De Computacao SA"},
{ {0x00, 0xC0, 0x25,0x00,0x00,0x00}, "Dataproducts Corporation"},
{ {0x00, 0xC0, 0x27,0x00,0x00,0x00}, "Cipher Systems, Inc."},
{ {0x00, 0xC0, 0x28,0x00,0x00,0x00}, "Jasco Corporation"},
{ {0x00, 0xC0, 0x29,0x00,0x00,0x00}, "Kabel Rheydt AG"},
{ {0x00, 0xC0, 0x2A,0x00,0x00,0x00}, "Ohkura Electric Co"},
{ {0x00, 0xC0, 0x2B,0x00,0x00,0x00}, "Gerloff Gesellschaft Fur"},
{ {0x00, 0xC0, 0x2C,0x00,0x00,0x00}, "Centrum Communications, Inc."},
{ {0x00, 0xC0, 0x2D,0x00,0x00,0x00}, "Fuji Photo Film Co., Ltd."},
{ {0x00, 0xC0, 0x2E,0x00,0x00,0x00}, "Netwiz"},
{ {0x00, 0xC0, 0x2F,0x00,0x00,0x00}, "Okuma Corp"},
{ {0x00, 0xC0, 0x30,0x00,0x00,0x00}, "Integrated Engineering B. V."},
{ {0x00, 0xC0, 0x31,0x00,0x00,0x00}, "Design Research Systems, Inc."},
{ {0x00, 0xC0, 0x32,0x00,0x00,0x00}, "I-Cubed Limited"},
{ {0x00, 0xC0, 0x33,0x00,0x00,0x00}, "Telebit Corporation"},
{ {0x00, 0xC0, 0x34,0x00,0x00,0x00}, "Dale Computer Corporation"},
{ {0x00, 0xC0, 0x35,0x00,0x00,0x00}, "Quintar Company"},
{ {0x00, 0xC0, 0x36,0x00,0x00,0x00}, "Raytech Electronic Corp"},
{ {0x00, 0xC0, 0x39,0x00,0x00,0x00}, "Silicon Systems"},
{ {0x00, 0xC0, 0x3B,0x00,0x00,0x00}, "Multiaccess Computing Corp"},
{ {0x00, 0xC0, 0x3C,0x00,0x00,0x00}, "Tower Tech S.R.L."},
{ {0x00, 0xC0, 0x3D,0x00,0x00,0x00}, "Wiesemann & Theis Gmbh"},
{ {0x00, 0xC0, 0x3E,0x00,0x00,0x00}, "Fa. Gebr. Heller Gmbh"},
{ {0x00, 0xC0, 0x3F,0x00,0x00,0x00}, "Stores Automated Systems Inc"},
{ {0x00, 0xC0, 0x40,0x00,0x00,0x00}, "ECCI"},
{ {0x00, 0xC0, 0x41,0x00,0x00,0x00}, "Digital Transmission Systems"},
{ {0x00, 0xC0, 0x42,0x00,0x00,0x00}, "Datalux Corp."},
{ {0x00, 0xC0, 0x43,0x00,0x00,0x00}, "Stratacom"},
{ {0x00, 0xC0, 0x44,0x00,0x00,0x00}, "Emcom Corporation"},
{ {0x00, 0xC0, 0x45,0x00,0x00,0x00}, "Isolation Systems Inc"},
{ {0x00, 0xC0, 0x46,0x00,0x00,0x00}, "Kemitron Ltd"},
{ {0x00, 0xC0, 0x47,0x00,0x00,0x00}, "Unimicro Systems Inc"},
{ {0x00, 0xC0, 0x48,0x00,0x00,0x00}, "Bay Technical Associates"},
{ {0x00, 0xC0, 0x49,0x00,0x00,0x00}, "US Robotics Total Control (tm) NETServer Card"},
{ {0x00, 0xC0, 0x4D,0x00,0x00,0x00}, "Mitec Ltd"},
{ {0x00, 0xC0, 0x4E,0x00,0x00,0x00}, "Comtrol Corporation"},
{ {0x00, 0xC0, 0x4F,0x00,0x00,0x00}, "Dell"},
{ {0x00, 0xC0, 0x50,0x00,0x00,0x00}, "Toyo Denki Seizo K.K."},
{ {0x00, 0xC0, 0x51,0x00,0x00,0x00}, "Advanced Integration Research"},
{ {0x00, 0xC0, 0x55,0x00,0x00,0x00}, "Modular Computing Technologies"},
{ {0x00, 0xC0, 0x56,0x00,0x00,0x00}, "Somelec"},
{ {0x00, 0xC0, 0x57,0x00,0x00,0x00}, "Myco Electronics"},
{ {0x00, 0xC0, 0x58,0x00,0x00,0x00}, "Dataexpert Corp"},
{ {0x00, 0xC0, 0x59,0x00,0x00,0x00}, "Nippondenso Corp"},
{ {0x00, 0xC0, 0x5B,0x00,0x00,0x00}, "Networks Northwest Inc"},
{ {0x00, 0xC0, 0x5C,0x00,0x00,0x00}, "Elonex PLC"},
{ {0x00, 0xC0, 0x5D,0x00,0x00,0x00}, "L&N Technologies"},
{ {0x00, 0xC0, 0x5E,0x00,0x00,0x00}, "Vari-Lite Inc"},
{ {0x00, 0xC0, 0x60,0x00,0x00,0x00}, "ID Scandinavia A/S"},
{ {0x00, 0xC0, 0x61,0x00,0x00,0x00}, "Solectek Corporation"},
{ {0x00, 0xC0, 0x63,0x00,0x00,0x00}, "Morning Star Technologies Inc May be miswrite of 0003C6"},
{ {0x00, 0xC0, 0x64,0x00,0x00,0x00}, "General Datacomm Ind Inc"},
{ {0x00, 0xC0, 0x65,0x00,0x00,0x00}, "Scope Communications Inc"},
{ {0x00, 0xC0, 0x66,0x00,0x00,0x00}, "Docupoint, Inc."},
{ {0x00, 0xC0, 0x67,0x00,0x00,0x00}, "United Barcode Industries"},
{ {0x00, 0xC0, 0x68,0x00,0x00,0x00}, "Philp Drake Electronics Ltd"},
{ {0x00, 0xC0, 0x69,0x00,0x00,0x00}, "California Microwave Inc"},
{ {0x00, 0xC0, 0x6A,0x00,0x00,0x00}, "Zahner-Elektrik Gmbh & Co KG"},
{ {0x00, 0xC0, 0x6B,0x00,0x00,0x00}, "OSI Plus Corporation"},
{ {0x00, 0xC0, 0x6C,0x00,0x00,0x00}, "SVEC Computer Corp"},
{ {0x00, 0xC0, 0x6D,0x00,0x00,0x00}, "Boca Research, Inc."},
{ {0x00, 0xC0, 0x6F,0x00,0x00,0x00}, "Komatsu Ltd"},
{ {0x00, 0xC0, 0x70,0x00,0x00,0x00}, "Sectra Secure-Transmission AB"},
{ {0x00, 0xC0, 0x71,0x00,0x00,0x00}, "Areanex Communications, Inc."},
{ {0x00, 0xC0, 0x72,0x00,0x00,0x00}, "KNX Ltd"},
{ {0x00, 0xC0, 0x73,0x00,0x00,0x00}, "Xedia Corporation"},
{ {0x00, 0xC0, 0x74,0x00,0x00,0x00}, "Toyoda Automatic Loom Works Ltd"},
{ {0x00, 0xC0, 0x75,0x00,0x00,0x00}, "Xante Corporation"},
{ {0x00, 0xC0, 0x76,0x00,0x00,0x00}, "I-Data International A-S"},
{ {0x00, 0xC0, 0x77,0x00,0x00,0x00}, "Daewoo Telecom Ltd"},
{ {0x00, 0xC0, 0x78,0x00,0x00,0x00}, "Computer Systems Engineering"},
{ {0x00, 0xC0, 0x79,0x00,0x00,0x00}, "Fonsys Co Ltd"},
{ {0x00, 0xC0, 0x7A,0x00,0x00,0x00}, "Priva BV"},
{ {0x00, 0xC0, 0x7B,0x00,0x00,0x00}, "Ascend Communications ISDN bridges/routers"},
{ {0x00, 0xC0, 0x7D,0x00,0x00,0x00}, "RISC Developments Ltd"},
{ {0x00, 0xC0, 0x7F,0x00,0x00,0x00}, "Nupon Computing Corp"},
{ {0x00, 0xC0, 0x80,0x00,0x00,0x00}, "Netstar Inc"},
{ {0x00, 0xC0, 0x81,0x00,0x00,0x00}, "Metrodata Ltd"},
{ {0x00, 0xC0, 0x82,0x00,0x00,0x00}, "Moore Products Co"},
{ {0x00, 0xC0, 0x84,0x00,0x00,0x00}, "Data Link Corp Ltd"},
{ {0x00, 0xC0, 0x85,0x00,0x00,0x00}, "Canon"},
{ {0x00, 0xC0, 0x86,0x00,0x00,0x00}, "The Lynk Corporation"},
{ {0x00, 0xC0, 0x87,0x00,0x00,0x00}, "UUNET Technologies Inc"},
{ {0x00, 0xC0, 0x89,0x00,0x00,0x00}, "Telindus Distribution"},
{ {0x00, 0xC0, 0x8A,0x00,0x00,0x00}, "Lauterbach Datentechnik Gmbh"},
{ {0x00, 0xC0, 0x8B,0x00,0x00,0x00}, "RISQ Modular Systems Inc"},
{ {0x00, 0xC0, 0x8C,0x00,0x00,0x00}, "Performance Technologies Inc"},
{ {0x00, 0xC0, 0x8D,0x00,0x00,0x00}, "Tronix Product Development"},
{ {0x00, 0xC0, 0x8E,0x00,0x00,0x00}, "Network Information Technology"},
{ {0x00, 0xC0, 0x8F,0x00,0x00,0x00}, "Matsushita Electric Works, Ltd."},
{ {0x00, 0xC0, 0x90,0x00,0x00,0x00}, "Praim S.R.L."},
{ {0x00, 0xC0, 0x91,0x00,0x00,0x00}, "Jabil Circuit, Inc."},
{ {0x00, 0xC0, 0x92,0x00,0x00,0x00}, "Mennen Medical Inc"},
{ {0x00, 0xC0, 0x93,0x00,0x00,0x00}, "Alta Research Corp."},
{ {0x00, 0xC0, 0x95,0x00,0x00,0x00}, "Znyx (Network Appliance); Jupiter Systems (MX-700); Apple (G3) all seen"},
{ {0x00, 0xC0, 0x96,0x00,0x00,0x00}, "Tamura Corporation"},
{ {0x00, 0xC0, 0x97,0x00,0x00,0x00}, "Archipel SA"},
{ {0x00, 0xC0, 0x98,0x00,0x00,0x00}, "Chuntex Electronic Co., Ltd."},
{ {0x00, 0xC0, 0x9B,0x00,0x00,0x00}, "Reliance Comm/Tec, R-Tec Systems Inc"},
{ {0x00, 0xC0, 0x9C,0x00,0x00,0x00}, "TOA Electronic Ltd"},
{ {0x00, 0xC0, 0x9D,0x00,0x00,0x00}, "Distributed Systems Int'l, Inc."},
{ {0x00, 0xC0, 0x9F,0x00,0x00,0x00}, "Quanta Computer Inc"},
{ {0x00, 0xC0, 0xA0,0x00,0x00,0x00}, "Advance Micro Research, Inc."},
{ {0x00, 0xC0, 0xA1,0x00,0x00,0x00}, "Tokyo Denshi Sekei Co"},
{ {0x00, 0xC0, 0xA2,0x00,0x00,0x00}, "Intermedium A/S"},
{ {0x00, 0xC0, 0xA3,0x00,0x00,0x00}, "Dual Enterprises Corporation"},
{ {0x00, 0xC0, 0xA4,0x00,0x00,0x00}, "Unigraf OY"},
{ {0x00, 0xC0, 0xA7,0x00,0x00,0x00}, "SEEL Ltd"},
{ {0x00, 0xC0, 0xA8,0x00,0x00,0x00}, "GVC Corporation"},
{ {0x00, 0xC0, 0xA9,0x00,0x00,0x00}, "Barron McCann Ltd"},
{ {0x00, 0xC0, 0xAA,0x00,0x00,0x00}, "Silicon Valley Computer"},
{ {0x00, 0xC0, 0xAB,0x00,0x00,0x00}, "Jupiter Technology Inc"},
{ {0x00, 0xC0, 0xAC,0x00,0x00,0x00}, "Gambit Computer Communications"},
{ {0x00, 0xC0, 0xAD,0x00,0x00,0x00}, "Computer Communication Systems"},
{ {0x00, 0xC0, 0xAE,0x00,0x00,0x00}, "Towercom Co Inc DBA PC House"},
{ {0x00, 0xC0, 0xB0,0x00,0x00,0x00}, "GCC Technologies,Inc."},
{ {0x00, 0xC0, 0xB2,0x00,0x00,0x00}, "Norand Corporation"},
{ {0x00, 0xC0, 0xB3,0x00,0x00,0x00}, "Comstat Datacomm Corporation"},
{ {0x00, 0xC0, 0xB4,0x00,0x00,0x00}, "Myson Technology Inc"},
{ {0x00, 0xC0, 0xB5,0x00,0x00,0x00}, "Corporate Network Systems Inc"},
{ {0x00, 0xC0, 0xB6,0x00,0x00,0x00}, "Meridian Data Inc"},
{ {0x00, 0xC0, 0xB7,0x00,0x00,0x00}, "American Power Conversion Corp"},
{ {0x00, 0xC0, 0xB8,0x00,0x00,0x00}, "Fraser's Hill Ltd."},
{ {0x00, 0xC0, 0xB9,0x00,0x00,0x00}, "Funk Software Inc"},
{ {0x00, 0xC0, 0xBA,0x00,0x00,0x00}, "Netvantage"},
{ {0x00, 0xC0, 0xBB,0x00,0x00,0x00}, "Forval Creative Inc"},
{ {0x00, 0xC0, 0xBD,0x00,0x00,0x00}, "Inex Technologies, Inc."},
{ {0x00, 0xC0, 0xBE,0x00,0x00,0x00}, "Alcatel - Sel"},
{ {0x00, 0xC0, 0xBF,0x00,0x00,0x00}, "Technology Concepts Ltd"},
{ {0x00, 0xC0, 0xC0,0x00,0x00,0x00}, "Shore Microsystems Inc"},
{ {0x00, 0xC0, 0xC1,0x00,0x00,0x00}, "Quad/Graphics Inc"},
{ {0x00, 0xC0, 0xC2,0x00,0x00,0x00}, "Infinite Networks Ltd."},
{ {0x00, 0xC0, 0xC3,0x00,0x00,0x00}, "Acuson Computed Sonography"},
{ {0x00, 0xC0, 0xC4,0x00,0x00,0x00}, "Computer Operational"},
{ {0x00, 0xC0, 0xC5,0x00,0x00,0x00}, "SID Informatica"},
{ {0x00, 0xC0, 0xC6,0x00,0x00,0x00}, "Personal Media Corp"},
{ {0x00, 0xC0, 0xC8,0x00,0x00,0x00}, "Micro Byte Pty Ltd"},
{ {0x00, 0xC0, 0xC9,0x00,0x00,0x00}, "Bailey Controls Co"},
{ {0x00, 0xC0, 0xCA,0x00,0x00,0x00}, "Alfa, Inc."},
{ {0x00, 0xC0, 0xCB,0x00,0x00,0x00}, "Control Technology Corporation"},
{ {0x00, 0xC0, 0xCD,0x00,0x00,0x00}, "Comelta S.A."},
{ {0x00, 0xC0, 0xD0,0x00,0x00,0x00}, "Ratoc System Inc"},
{ {0x00, 0xC0, 0xD1,0x00,0x00,0x00}, "Comtree Technology Corporation (EFA also reported)"},
{ {0x00, 0xC0, 0xD2,0x00,0x00,0x00}, "Syntellect Inc"},
{ {0x00, 0xC0, 0xD4,0x00,0x00,0x00}, "Axon Networks Inc"},
{ {0x00, 0xC0, 0xD5,0x00,0x00,0x00}, "Quancom Electronic Gmbh"},
{ {0x00, 0xC0, 0xD6,0x00,0x00,0x00}, "J1 Systems, Inc."},
{ {0x00, 0xC0, 0xD9,0x00,0x00,0x00}, "Quinte Network Confidentiality Equipment Inc"},
{ {0x00, 0xC0, 0xDB,0x00,0x00,0x00}, "IPC Corporation (Pte) Ltd"},
{ {0x00, 0xC0, 0xDC,0x00,0x00,0x00}, "EOS Technologies, Inc."},
{ {0x00, 0xC0, 0xDE,0x00,0x00,0x00}, "ZComm Inc"},
{ {0x00, 0xC0, 0xDF,0x00,0x00,0x00}, "Kye Systems Corp"},
{ {0x00, 0xC0, 0xE1,0x00,0x00,0x00}, "Sonic Solutions"},
{ {0x00, 0xC0, 0xE2,0x00,0x00,0x00}, "Calcomp, Inc."},
{ {0x00, 0xC0, 0xE3,0x00,0x00,0x00}, "Ositech Communications Inc"},
{ {0x00, 0xC0, 0xE4,0x00,0x00,0x00}, "Landis & Gyr Powers Inc"},
{ {0x00, 0xC0, 0xE5,0x00,0x00,0x00}, "GESPAC S.A."},
{ {0x00, 0xC0, 0xE6,0x00,0x00,0x00}, "TXPORT"},
{ {0x00, 0xC0, 0xE7,0x00,0x00,0x00}, "Fiberdata AB"},
{ {0x00, 0xC0, 0xE8,0x00,0x00,0x00}, "Plexcom Inc"},
{ {0x00, 0xC0, 0xE9,0x00,0x00,0x00}, "Oak Solutions Ltd"},
{ {0x00, 0xC0, 0xEA,0x00,0x00,0x00}, "Array Technology Ltd."},
{ {0x00, 0xC0, 0xEC,0x00,0x00,0x00}, "Dauphin Technology"},
{ {0x00, 0xC0, 0xED,0x00,0x00,0x00}, "US Army Electronic Proving Ground"},
{ {0x00, 0xC0, 0xEE,0x00,0x00,0x00}, "Kyocera Corporation"},
{ {0x00, 0xC0, 0xEF,0x00,0x00,0x00}, "Abit Corporation"},
{ {0x00, 0xC0, 0xF0,0x00,0x00,0x00}, "Kingston Technology Corporation"},
{ {0x00, 0xC0, 0xF1,0x00,0x00,0x00}, "Shinko Electric Co Ltd"},
{ {0x00, 0xC0, 0xF2,0x00,0x00,0x00}, "Transition Engineering Inc"},
{ {0x00, 0xC0, 0xF3,0x00,0x00,0x00}, "Network Communications Corp"},
{ {0x00, 0xC0, 0xF4,0x00,0x00,0x00}, "Interlink System Co., Ltd."},
{ {0x00, 0xC0, 0xF5,0x00,0x00,0x00}, "Metacomp Inc"},
{ {0x00, 0xC0, 0xF6,0x00,0x00,0x00}, "Celan Technology Inc."},
{ {0x00, 0xC0, 0xF7,0x00,0x00,0x00}, "Engage Communication, Inc."},
{ {0x00, 0xC0, 0xF8,0x00,0x00,0x00}, "About Computing Inc."},
{ {0x00, 0xC0, 0xFA,0x00,0x00,0x00}, "Canary Communications Inc"},
{ {0x00, 0xC0, 0xFB,0x00,0x00,0x00}, "Advanced Technology Labs"},
{ {0x00, 0xC0, 0xFC,0x00,0x00,0x00}, "ASDG Incorporated"},
{ {0x00, 0xC0, 0xFD,0x00,0x00,0x00}, "Prosum"},
{ {0x00, 0xC0, 0xFF,0x00,0x00,0x00}, "Box Hill Systems Corporation"},
{ {0x00, 0xDD, 0x00,0x00,0x00,0x00}, "Ungermann-Bass IBM RT"},
{ {0x00, 0xDD, 0x01,0x00,0x00,0x00}, "Ungermann-Bass"},
{ {0x00, 0xDD, 0x08,0x00,0x00,0x00}, "Ungermann-Bass"},
{ {0x00, 0xE0, 0x11,0x00,0x00,0x00}, "Uniden Corporation"},
{ {0x00, 0xE0, 0x14,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0xE0, 0x16,0x00,0x00,0x00}, "rapid-city (now a part of bay networks)"},
{ {0x00, 0xE0, 0x18,0x00,0x00,0x00}, "Asustek Intel 82558-based Integrated Fast Ethernet for WIM"},
{ {0x00, 0xE0, 0x1E,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0xE0, 0x29,0x00,0x00,0x00}, "SMC EtherPower II 10/100"},
{ {0x00, 0xE0, 0x2C,0x00,0x00,0x00}, "AST - built into 5166M PC motherboard (win95 id's as Intel)"},
{ {0x00, 0xE0, 0x34,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0xE0, 0x39,0x00,0x00,0x00}, "Paradyne 7112 T1 DSU/CSU"},
{ {0x00, 0xE0, 0x4F,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0xE0, 0x7D,0x00,0x00,0x00}, "Encore (Netronix?) 10/100 PCI Fast ethernet card"},
{ {0x00, 0xE0, 0x81,0x00,0x00,0x00}, "Tyan Computer Corp. Onboard Intel 82558 10/100"},
{ {0x00, 0xE0, 0x83,0x00,0x00,0x00}, "Jato Technologies, Inc."},
{ {0x00, 0xE0, 0x8F,0x00,0x00,0x00}, "Cisco Systems Catalyst 2900 series"},
{ {0x00, 0xE0, 0x98,0x00,0x00,0x00}, "Linksys PCMCIA card"},
{ {0x00, 0xE0, 0xA3,0x00,0x00,0x00}, "Cisco Systems Catalyst 1924"},
{ {0x00, 0xE0, 0xB0,0x00,0x00,0x00}, "Cisco Systems Various systems reported"},
{ {0x00, 0xE0, 0xB8,0x00,0x00,0x00}, "AMD PCNet in a Gateway 2000"},
{ {0x00, 0xE0, 0xC5,0x00,0x00,0x00}, "BCOM Electronics Inc."},
{ {0x00, 0xE0, 0xED,0x00,0x00,0x00}, "New Link"},
{ {0x00, 0xE0, 0xF7,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0xE0, 0xF9,0x00,0x00,0x00}, "Cisco"},
{ {0x00, 0xE0, 0xFE,0x00,0x00,0x00}, "Cisco"},
{ {0x02, 0x04, 0x06,0x00,0x00,0x00}, "BBN internal usage (not registered)"},
{ {0x02, 0x07, 0x01,0x00,0x00,0x00}, "Interlan [now Racal-InterLAN] DEC (UNIBUS or QBUS), Apollo, Cisco"},
{ {0x02, 0x07, 0x01,0x00,0x00,0x00}, "Racal-Datacom"},
{ {0x02, 0x60, 0x60,0x00,0x00,0x00}, "3Com"},
{ {0x02, 0x60, 0x86,0x00,0x00,0x00}, "Satelcom MegaPac (UK)"},
{ {0x02, 0x60, 0x8C,0x00,0x00,0x00}, "3Com IBM PC; Imagen; Valid; Cisco; Macintosh"},
{ {0x02, 0xA0, 0xC9,0x00,0x00,0x00}, "Intel"},
{ {0x02, 0xAA, 0x3C,0x00,0x00,0x00}, "Olivetti"},
{ {0x02, 0xCF, 0x1F,0x00,0x00,0x00}, "CMC Masscomp; Silicon Graphics; Prime EXL"},
{ {0x02, 0xE0, 0x3B,0x00,0x00,0x00}, "Prominet Corporation Gigabit Ethernet Switch"},
{ {0x02, 0xE6, 0xD3,0x00,0x00,0x00}, "BTI (Bus-Tech, Inc.) IBM Mainframes"},
{ {0x04, 0x88, 0x45,0x00,0x00,0x00}, "Bay Networks token ring line card"},
{ {0x08, 0x00, 0x01,0x00,0x00,0x00}, "Computer Vision"},
{ {0x08, 0x00, 0x02,0x00,0x00,0x00}, "3Com (formerly Bridge)"},
{ {0x08, 0x00, 0x03,0x00,0x00,0x00}, "ACC (Advanced Computer Communications)"},
{ {0x08, 0x00, 0x05,0x00,0x00,0x00}, "Symbolics Symbolics LISP machines"},
{ {0x08, 0x00, 0x06,0x00,0x00,0x00}, "Siemens Nixdorf PC clone"},
{ {0x08, 0x00, 0x07,0x00,0x00,0x00}, "Apple"},
{ {0x08, 0x00, 0x08,0x00,0x00,0x00}, "BBN (Bolt Beranek and Newman, Inc.)"},
{ {0x08, 0x00, 0x09,0x00,0x00,0x00}, "Hewlett-Packard"},
{ {0x08, 0x00, 0x0A,0x00,0x00,0x00}, "Nestar Systems"},
{ {0x08, 0x00, 0x0B,0x00,0x00,0x00}, "Unisys also Ascom-Timeplex (former Unisys subsidiary)"},
{ {0x08, 0x00, 0x0D,0x00,0x00,0x00}, "ICL (International Computers, Ltd.)"},
{ {0x08, 0x00, 0x0E,0x00,0x00,0x00}, "NCR/AT&T"},
{ {0x08, 0x00, 0x0F,0x00,0x00,0x00}, "SMC (Standard Microsystems Corp.)"},
{ {0x08, 0x00, 0x10,0x00,0x00,0x00}, "AT&T [misrepresentation of 800010?]"},
{ {0x08, 0x00, 0x11,0x00,0x00,0x00}, "Tektronix, Inc."},
{ {0x08, 0x00, 0x14,0x00,0x00,0x00}, "Excelan BBN Butterfly, Masscomp, Silicon Graphics"},
{ {0x08, 0x00, 0x17,0x00,0x00,0x00}, "National Semiconductor Corp. (used to have Network System Corp., wrong NSC)"},
{ {0x08, 0x00, 0x1A,0x00,0x00,0x00}, "Tiara? (used to have Data General)"},
{ {0x08, 0x00, 0x1B,0x00,0x00,0x00}, "Data General"},
{ {0x08, 0x00, 0x1E,0x00,0x00,0x00}, "Apollo"},
{ {0x08, 0x00, 0x1F,0x00,0x00,0x00}, "Sharp"},
{ {0x08, 0x00, 0x20,0x00,0x00,0x00}, "Sun"},
{ {0x08, 0x00, 0x22,0x00,0x00,0x00}, "NBI (Nothing But Initials)"},
{ {0x08, 0x00, 0x23,0x00,0x00,0x00}, "Matsushita Denso"},
{ {0x08, 0x00, 0x25,0x00,0x00,0x00}, "CDC"},
{ {0x08, 0x00, 0x26,0x00,0x00,0x00}, "Norsk Data (Nord)"},
{ {0x08, 0x00, 0x27,0x00,0x00,0x00}, "PCS Computer Systems GmbH"},
{ {0x08, 0x00, 0x28,0x00,0x00,0x00}, "TI Explorer"},
{ {0x08, 0x00, 0x2B,0x00,0x00,0x00}, "DEC"},
{ {0x08, 0x00, 0x2E,0x00,0x00,0x00}, "Metaphor"},
{ {0x08, 0x00, 0x2F,0x00,0x00,0x00}, "Prime Computer Prime 50-Series LHC300"},
{ {0x08, 0x00, 0x30,0x00,0x00,0x00}, "CERN"},
{ {0x08, 0x00, 0x32,0x00,0x00,0x00}, "Tigan"},
{ {0x08, 0x00, 0x36,0x00,0x00,0x00}, "Intergraph CAE stations"},
{ {0x08, 0x00, 0x37,0x00,0x00,0x00}, "Fuji Xerox"},
{ {0x08, 0x00, 0x38,0x00,0x00,0x00}, "Bull"},
{ {0x08, 0x00, 0x39,0x00,0x00,0x00}, "Spider Systems"},
{ {0x08, 0x00, 0x3B,0x00,0x00,0x00}, "Torus Systems"},
{ {0x08, 0x00, 0x3D,0x00,0x00,0x00}, "cadnetix"},
{ {0x08, 0x00, 0x3E,0x00,0x00,0x00}, "Motorola VME bus processor modules"},
{ {0x08, 0x00, 0x41,0x00,0x00,0x00}, "DCA (Digital Comm. Assoc.)"},
{ {0x08, 0x00, 0x44,0x00,0x00,0x00}, "DSI (DAVID Systems, Inc.)"},
{ {0x08, 0x00, 0x45,0x00,0x00,0x00}, "data (maybe Xylogics, but they claim not to know this number)"},
{ {0x08, 0x00, 0x46,0x00,0x00,0x00}, "Sony"},
{ {0x08, 0x00, 0x47,0x00,0x00,0x00}, "Sequent"},
{ {0x08, 0x00, 0x48,0x00,0x00,0x00}, "Eurotherm Gauging Systems"},
{ {0x08, 0x00, 0x49,0x00,0x00,0x00}, "Univation"},
{ {0x08, 0x00, 0x4C,0x00,0x00,0x00}, "Encore"},
{ {0x08, 0x00, 0x4E,0x00,0x00,0x00}, "BICC [3com bought BICC, so may appear on 3com equipment as well]"},
{ {0x08, 0x00, 0x51,0x00,0x00,0x00}, "Experdata"},
{ {0x08, 0x00, 0x56,0x00,0x00,0x00}, "Stanford University"},
{ {0x08, 0x00, 0x57,0x00,0x00,0x00}, "Evans & Sutherland (?)"},
{ {0x08, 0x00, 0x58,0x00,0x00,0x00}, "??? DECsystem-20"},
{ {0x08, 0x00, 0x5A,0x00,0x00,0x00}, "IBM"},
{ {0x08, 0x00, 0x66,0x00,0x00,0x00}, "AGFA printers, phototypesetters etc."},
{ {0x08, 0x00, 0x67,0x00,0x00,0x00}, "Comdesign"},
{ {0x08, 0x00, 0x68,0x00,0x00,0x00}, "Ridge"},
{ {0x08, 0x00, 0x69,0x00,0x00,0x00}, "Silicon Graphics"},
{ {0x08, 0x00, 0x6A,0x00,0x00,0x00}, "ATTst (?)"},
{ {0x08, 0x00, 0x6E,0x00,0x00,0x00}, "Excelan"},
{ {0x08, 0x00, 0x70,0x00,0x00,0x00}, "Mitsubishi"},
{ {0x08, 0x00, 0x74,0x00,0x00,0x00}, "Casio"},
{ {0x08, 0x00, 0x75,0x00,0x00,0x00}, "DDE (Danish Data Elektronik A/S)"},
{ {0x08, 0x00, 0x77,0x00,0x00,0x00}, "TSL (now Retix)"},
{ {0x08, 0x00, 0x79,0x00,0x00,0x00}, "Silicon Graphics"},
{ {0x08, 0x00, 0x7C,0x00,0x00,0x00}, "Vitalink TransLAN III"},
{ {0x08, 0x00, 0x80,0x00,0x00,0x00}, "XIOS"},
{ {0x08, 0x00, 0x81,0x00,0x00,0x00}, "Crosfield Electronics"},
{ {0x08, 0x00, 0x83,0x00,0x00,0x00}, "Seiko Denshi"},
{ {0x08, 0x00, 0x86,0x00,0x00,0x00}, "Imagen/QMS"},
{ {0x08, 0x00, 0x87,0x00,0x00,0x00}, "Xyplex terminal servers"},
{ {0x08, 0x00, 0x88,0x00,0x00,0x00}, "McDATA Corporation"},
{ {0x08, 0x00, 0x89,0x00,0x00,0x00}, "Kinetics AppleTalk-Ethernet interface"},
{ {0x08, 0x00, 0x8B,0x00,0x00,0x00}, "Pyramid"},
{ {0x08, 0x00, 0x8D,0x00,0x00,0x00}, "XyVision XyVision machines"},
{ {0x08, 0x00, 0x8E,0x00,0x00,0x00}, "Tandem / Solbourne Computer ?"},
{ {0x08, 0x00, 0x8F,0x00,0x00,0x00}, "Chipcom Corp."},
{ {0x08, 0x00, 0x90,0x00,0x00,0x00}, "Retix, Inc. Bridges"},
{ {0x09, 0x00, 0x6A,0x00,0x00,0x00}, "AT&T"},
{ {0x10, 0x00, 0x5A,0x00,0x00,0x00}, "IBM"},
{ {0x10, 0x00, 0x90,0x00,0x00,0x00}, "Hewlett-Packard Advisor products"},
{ {0x10, 0x00, 0xD4,0x00,0x00,0x00}, "DEC"},
{ {0x10, 0x00, 0xE0,0x00,0x00,0x00}, "Apple A/UX (modified addresses for licensing)"},
{ {0x2E, 0x2E, 0x2E,0x00,0x00,0x00}, "LAA (Locally Administered Address) for Meditech Systems"},
{ {0x3C, 0x00, 0x00,0x00,0x00,0x00}, "3Com dual function (V.34 modem + Ethernet) card"},
{ {0x40, 0x00, 0x03,0x00,0x00,0x00}, "Net Ware (?)"},
{ {0x44, 0x45, 0x53,0x00,0x00,0x00}, "Microsoft (Windows95 internal adapters)"},
{ {0x44, 0x46, 0x49,0x00,0x00,0x00}, "DFI (Diamond Flower Industries)"},
{ {0x47, 0x54, 0x43,0x00,0x00,0x00}, "GTC (Not registered!) (This number is a multicast!)"},
{ {0x48, 0x44, 0x53,0x00,0x00,0x00}, "HDS ???"},
{ {0x48, 0x4C, 0x00,0x00,0x00,0x00}, "Network Solutions"},
{ {0x48, 0x54, 0xE8,0x00,0x00,0x00}, "winbond?"},
{ {0x4C, 0x42, 0x4C,0x00,0x00,0x00}, "Information Modes software modified addresses (not registered?)"},
{ {0x52, 0x54, 0x00,0x00,0x00,0x00}, "Realtek (UpTech? also reported)"},
{ {0x52, 0x54, 0x4C,0x00,0x00,0x00}, "Novell 2000"},
{ {0x52, 0x54, 0xAB,0x00,0x00,0x00}, "REALTEK (a Realtek 8029 based PCI Card)"},
{ {0x56, 0x58, 0x57,0x00,0x00,0x00}, "Aculab plc audio bridges"},
{ {0x80, 0x00, 0x10,0x00,0x00,0x00}, "AT&T [misrepresented as 080010? One source claims this is correct]"},
{ {0x80, 0xAD, 0x00,0x00,0x00,0x00}, "CNET Technology Inc. (Probably an error, see instead 0080AD)"},
{ {0xAA, 0x00, 0x00,0x00,0x00,0x00}, "DEC obsolete"},
{ {0xAA, 0x00, 0x01,0x00,0x00,0x00}, "DEC obsolete"},
{ {0xAA, 0x00, 0x02,0x00,0x00,0x00}, "DEC obsolete"},
{ {0xAA, 0x00, 0x03,0x00,0x00,0x00}, "DEC Global physical address for some DEC machines"},
{ {0xAA, 0x00, 0x04,0x00,0x00,0x00}, "DEC Local logical address for DECNET systems"},
{ {0xC0, 0x00, 0x00,0x00,0x00,0x00}, "Western Digital (may be reversed 00 00 C0?)"},
{ {0xEC, 0x10, 0x00,0x00,0x00,0x00}, "Enance Source Co., Ltd. PC clones(?)"},
{ {0xE2, 0x0C, 0x0F,0x00,0x00,0x00}, "Kingston Technologies"},
{ {0x00, 0x00, 0x00,0x00,0x00,0x00}, NULL}
};


#endif /* do we want 48BIT arp ? */
#endif /* do we want arp ? */
